<?php
session_start(); // Start the session

// Check if the admin is logged in
if (!isset($_SESSION['admin_id'])) {
    // If not logged in, redirect to the login page
    header("Location: admin_login.php");
    exit();
}

// Retrieve admin details from session variables
$admin_name = $_SESSION['admin_name'];
$admin_email = $_SESSION['admin_email'];
$admin_initials = $_SESSION['admin_initials'];
// Include the database connection
include 'conn.php';

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['add_about'])) {
        // Add new about section
        $descriptionOne = $_POST['description_one'];
        $goalList = $_POST['goal_list'];
        $showBuyTicket = isset($_POST['show_buy_ticket']) ? 1 : 0;
        $buyTicketUrl = $_POST['buy_ticket_url'] ?? '';
        $showBecomeSponsor = isset($_POST['show_become_sponsor']) ? 1 : 0;
        $becomeSponsorUrl = $_POST['become_sponsor_url'] ?? '';
        $imagePath = '';

        // Handle image upload
        if (isset($_FILES['image']['tmp_name']) && $_FILES['image']['tmp_name'] !== '') {
            $imagePath = 'imagesconf/about/' . basename($_FILES['image']['name']);
            if (move_uploaded_file($_FILES['image']['tmp_name'], $imagePath)) {
                // Success
            } else {
                echo 'Error uploading file.';
                $imagePath = ''; // Fallback if upload fails
            }
        }

        // Prepare and execute insert query
        $query = "INSERT INTO about (description_one, goal_list, image_path, show_buy_ticket, buy_ticket_url, show_become_sponsor, become_sponsor_url) VALUES (:description_one, :goal_list, :image_path, :show_buy_ticket, :buy_ticket_url, :show_become_sponsor, :become_sponsor_url)";
        $stmt = $conn->prepare($query);
        $stmt->execute([
            ':description_one' => $descriptionOne,
            ':goal_list' => $goalList,
            ':image_path' => $imagePath,
            ':show_buy_ticket' => $showBuyTicket,
            ':buy_ticket_url' => $buyTicketUrl,
            ':show_become_sponsor' => $showBecomeSponsor,
            ':become_sponsor_url' => $becomeSponsorUrl,
        ]);
        echo 'New section added successfully!';
    } elseif (isset($_POST['edit_about'])) {
        // Edit existing about section
        $id = $_POST['id'];
        $descriptionOne = $_POST['description_one'];
        $goalList = $_POST['goal_list'];
        $showBuyTicket = isset($_POST['show_buy_ticket']) ? 1 : 0;
        $buyTicketUrl = $_POST['buy_ticket_url'] ?? '';
        $showBecomeSponsor = isset($_POST['show_become_sponsor']) ? 1 : 0;
        $becomeSponsorUrl = $_POST['become_sponsor_url'] ?? '';
        $oldImagePath = $_POST['old_image_path'];
        $newImagePath = $oldImagePath;

        // Handle image upload
        if (isset($_FILES['image']['tmp_name']) && $_FILES['image']['tmp_name'] !== '') {
            $newImagePath = 'imagesconf/about/' . basename($_FILES['image']['name']);
            if (move_uploaded_file($_FILES['image']['tmp_name'], $newImagePath)) {
                // Unlink old image if it exists
                if ($oldImagePath && file_exists($oldImagePath)) {
                    unlink($oldImagePath);
                }
            } else {
                echo 'Error uploading file.';
                $newImagePath = $oldImagePath; // Fallback if upload fails
            }
        }

        // Prepare and execute update query
        $query = "UPDATE about 
                  SET description_one = :description_one, 
                      goal_list = :goal_list, 
                      image_path = :image_path, 
                      show_buy_ticket = :show_buy_ticket, 
                      buy_ticket_url = :buy_ticket_url, 
                      show_become_sponsor = :show_become_sponsor, 
                      become_sponsor_url = :become_sponsor_url 
                  WHERE id = :id";

        $stmt = $conn->prepare($query);
        $stmt->execute([
            ':description_one' => $descriptionOne,
            ':goal_list' => $goalList,
            ':image_path' => $newImagePath,
            ':show_buy_ticket' => $showBuyTicket,
            ':buy_ticket_url' => $buyTicketUrl,
            ':show_become_sponsor' => $showBecomeSponsor,
            ':become_sponsor_url' => $becomeSponsorUrl,
            ':id' => $id,
        ]);
        echo 'Section updated successfully!';
    } elseif (isset($_POST['delete_about'])) {
        // Delete about section
        $id = $_POST['id'];
        $query = "SELECT image_path FROM about WHERE id = :id";
        $stmt = $conn->prepare($query);
        $stmt->execute([':id' => $id]);
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        $imagePath = $row['image_path'];

        $query = "DELETE FROM about WHERE id = :id";
        $stmt = $conn->prepare($query);
        $stmt->execute([':id' => $id]);

        // Unlink image if it exists
        if ($imagePath && file_exists($imagePath)) {
            unlink($imagePath);
        }

        echo 'Section deleted successfully!';
    }
}

// Fetch about section data for display
$query = "SELECT * FROM about";
$stmt = $conn->prepare($query);
$stmt->execute();
$aboutItems = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard</title>
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css" rel="stylesheet">
    <link href="imagesconf/icon2.png" rel="shortcut icon">
    <style>
    body {
        font-family: Arial, sans-serif;
        background-color: #f8f9fa;
    }

    .navbar {
        background-color: #343a40;
    }

    .navbar-brand {
        color: #fff;
        font-weight: bold;
    }

    .sidebar {
        height: 100vh;
        background-color: #343a40;
        padding-top: 20px;
    }

    .sidebar a {
        color: #ddd;
        padding: 15px;
        display: block;
        font-size: 16px;
        text-decoration: none;
    }

    .sidebar a:hover {
        background-color: #495057;
        color: #fff;
    }

    .content {
        padding: 20px;
        margin-left: 250px;
    }

    .card-header {
        background-color: #186F45;
        color: white;
        text-align: center;
    }

    .btn-primary {
        background-color: #186F45;
        border-color: #186F45;
    }

    .btn-primary:hover {
        background-color: #145536;
        border-color: #145536;
    }

    .content {
        padding: 20px;
    }

    .card {
        border: none;
        border-radius: 10px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
    }

    .card-header {
        background-color: black;
        border-bottom: 1px solid #dee2e6;
        border-top-left-radius: 10px;
        border-top-right-radius: 10px;
        padding: 15px;
    }

    .card-body {
        padding: 20px;
    }

    .table img {
        max-width: 100px;
        height: auto;
    }

    .btn-block {
        width: 100%;
    }

    .profile-image {
        display: inline-block;
        width: 40px;
        height: 40px;
        background-color: #007bff;
        color: #fff;
        text-align: center;
        line-height: 40px;
        border-radius: 50%;
        font-weight: bold;
        margin-right: 10px;
    }

    .profile-image span {
        font-size: 16px;
        text-transform: uppercase;
    }
    </style>
</head>

<body>

    <!-- Navbar -->
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">Admin Dashboard</a>
        <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
            aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav ml-auto">
                <!-- Profile Image (Initials) -->
                <li class="nav-item">
                    <div class="profile-image">
                        <span><?php echo $_SESSION['admin_initials']; ?></span>
                    </div>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#"><i class="fas fa-user-circle"></i> Profile</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="logout.php"><i class="fas fa-sign-out-alt"></i> Logout</a>
                </li>
            </ul>
        </div>
    </nav>
    <!-- Sidebar -->
    <div class="d-flex">
    <div class="sidebar">
        <a href="admin_main_header.php"><i class="fas fa-bookmark"></i> Add Main Header</a>

        <?php if ($_SESSION['user_type'] == 'superadmin') : ?>
            <!-- Show Approve Admins only for superadmin -->
            <a href="admin_approval.php"><i class="fas fa-book"></i> Approve Admins</a>
        <?php endif; ?>

        <!-- Show all other menus for both admin and superadmin -->
        <a href="about_admin.php"><i class="fas fa-tachometer-alt"></i> Add About</a>
        <a href="admin.php"><i class="fas fa-tachometer-alt"></i> Add Speakers</a>
        <a href="manage_speakers.php"><i class="fas fa-user"></i> Manage Speakers</a>
        <a href="manage_registrants.php"><i class="fas fa-user"></i> Manage Registrants</a>
        <a href="admin_schedules.php"><i class="fas fa-calendar"></i> Manage Event Schedule</a>
        <a href="admin_upload.php"><i class="fas fa-camera"></i> Add Gallery</a>
        <a href="confgallery.php"><i class="fas fa-camera"></i> Manage Gallery</a>
        <a href="admin_sponsors.php"><i class="fas fa-user"></i> Manage Sponsors</a>
        <a href="manage_sponsors.php"><i class="fas fa-briefcase"></i> List of Sponsors</a>
        <a href="admin_news.php"><i class="fas fa-book"></i> Manage News</a>
        <a href="price_table.php"><i class="fas fa-table"></i> Manage Price Table</a>
        <a href="zoom.php"><i class="fas fa-video"></i> Add Zoom Link</a>
        <a href="#"><i class="fas fa-cog"></i> Settings</a>
        <a href="#"><i class="fas fa-question-circle"></i> Help</a>
    </div>


        <!-- Admin Details Section -->
        <div class="container mt-5 flex-grow-1">
            <div class="card">
                <div class="card-header">
                    Admin Details
                </div>
                <div class="card-body">
                    <h2>Welcome, <?php echo $admin_name; ?></h2>
                    <p>Email: <?php echo $admin_email; ?></p>
                    <p>Initials: <?php echo $admin_initials; ?></p>
                </div>
            </div>

            <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">
            <img src="imagesconf/11th.png" alt="Logo">
        </a>
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
                <a class="nav-link btn btn-secondary" href="admin.php">Back to Dashboard</a>
            </li>
        </ul>
    </nav>

        <!----Addd Content----->
        <div class="container mt-5">
    <h1>Manage About Section</h1>

    <!-- Add New About Section -->
    <form action="" method="post" enctype="multipart/form-data">
        <h3>Add New Section</h3>
        <div class="form-group">
            <label for="description_one">Description One</label>
            <textarea id="description_one" name="description_one" class="form-control" required></textarea>
        </div>
        <div class="form-group">
            <label for="goal_list">Goal List (HTML allowed)</label>
            <textarea id="goal_list" name="goal_list" class="form-control" required></textarea>
        </div>
        <div class="form-group">
            <label for="image">Image</label>
            <input type="file" id="image" name="image" class="form-control" accept="image/*" required>
        </div>
        <div class="form-group">
            <label for="show_buy_ticket">Show "Buy Ticket" Button</label>
            <input type="checkbox" id="show_buy_ticket" name="show_buy_ticket" value="1" checked>
        </div>
        <div class="form-group">
            <label for="buy_ticket_link">"Buy Ticket" Button Link</label>
            <input type="text" id="buy_ticket_link" name="buy_ticket_link" class="form-control" value="#TISection">
        </div>
        <div class="form-group">
            <label for="show_become_sponsor">Show "Become a Sponsor" Button</label>
            <input type="checkbox" id="show_become_sponsor" name="show_become_sponsor" value="1" checked>
        </div>
        <div class="form-group">
            <label for="become_sponsor_link">"Become a Sponsor" Button Link</label>
            <input type="text" id="become_sponsor_link" name="become_sponsor_link" class="form-control" value="#">
        </div>
        <button type="submit" name="add_about" class="btn btn-primary">Add Section</button>
    </form>

    <!-- List Existing About Sections -->
    <h3 class="mt-5">Existing Sections</h3>
<?php if (!empty($aboutItems)): ?>
    <?php foreach ($aboutItems as $item): ?>
        <div class="card mb-3">
            <div class="card-body">
                <h5 class="card-title">Section ID: <?= htmlspecialchars($item['id']) ?></h5>
                <form action="" method="post" enctype="multipart/form-data">
                    <input type="hidden" name="id" value="<?= htmlspecialchars($item['id']) ?>">
                    <input type="hidden" name="old_image_path" value="<?= htmlspecialchars($item['image_path']) ?>">
                    <div class="form-group">
                        <label for="description_one_<?= $item['id'] ?>">Description One</label>
                        <textarea id="description_one_<?= $item['id'] ?>" name="description_one" class="form-control" required><?= htmlspecialchars($item['description_one']) ?></textarea>
                    </div>
                    <div class="form-group">
                        <label for="goal_list_<?= $item['id'] ?>">Goal List (HTML allowed)</label>
                        <textarea id="goal_list_<?= $item['id'] ?>" name="goal_list" class="form-control" required><?= htmlspecialchars($item['goal_list']) ?></textarea>
                    </div>
                    <div class="form-group">
                        <label for="image_<?= $item['id'] ?>">Image</label>
                        <input type="file" id="image_<?= $item['id'] ?>" name="image" class="form-control" accept="image/*">
                        <?php if ($item['image_path']): ?>
                            <img src="<?= htmlspecialchars($item['image_path']) ?>" alt="Current Image" class="img-fluid mt-2" style="max-width: 200px;">
                        <?php endif; ?>
                    </div>
                    <div class="form-group">
                        <label for="show_become_sponsor_<?= $item['id'] ?>">Show "Become a Sponsor" Button</label>
                        <input type="checkbox" id="show_become_sponsor_<?= $item['id'] ?>" name="show_become_sponsor" value="1" <?= $item['show_become_sponsor'] ? 'checked' : '' ?>>
                    </div>
                    <div class="form-group">
                        <label for="become_sponsor_link_<?= $item['id'] ?>">"Become a Sponsor" Button Link</label>
                        <input type="text" id="become_sponsor_link_<?= $item['id'] ?>" name="become_sponsor_link" class="form-control" value="<?= htmlspecialchars($item['become_sponsor_url']) ?>">
                    </div>
                    <button type="submit" name="edit_about" class="btn btn-warning">Edit Section</button>
                </form>
                <form action="" method="post" class="mt-2">
                    <input type="hidden" name="id" value="<?= htmlspecialchars($item['id']) ?>">
                    <button type="submit" name="delete_about" class="btn btn-danger">Delete Section</button>
                </form>
            </div>
        </div>
    <?php endforeach; ?>
<?php else: ?>
    <p>No sections available.</p>
<?php endif; ?>


</div>
        <!-- Bootstrap and FontAwesome Scripts -->
        <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
        <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.2/dist/umd/popper.min.js"></script>
        <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>

</html>