<?php
session_start(); // Start the session
include('conn.php'); // Database connection

$message = ''; // Initialize message for login feedback

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    if (isset($_POST['email']) && isset($_POST['password'])) {
        $email = $_POST['email'];
        $password = $_POST['password'];

        // Prepare SQL to select user by email
        $sql = "SELECT * FROM dtceadmin WHERE email = :email";
        $stmt = $conn->prepare($sql);
        $stmt->bindParam(':email', $email);
        $stmt->execute();
        
        // Check if the admin exists
        if ($stmt->rowCount() > 0) {
            $admin = $stmt->fetch(PDO::FETCH_ASSOC);
            
            // Check if the account is approved
            if ($admin['status'] == 'approved') {
                
                // Check if the user type is either admin or superadmin
                if ($admin['user_type'] == 'admin' || $admin['user_type'] == 'superadmin') {
                    
                    // Verify the password
                    if (password_verify($password, $admin['password'])) {
                        
                        // Password is correct, create session variables
                        $_SESSION['admin_id'] = $admin['id'];
                        $_SESSION['admin_name'] = $admin['name'];
                        $_SESSION['admin_email'] = $admin['email'];
                        $_SESSION['user_type'] = $admin['user_type']; // Save user type in session

                        // Extract initials for profile image name
                        $name_parts = explode(" ", $admin['name']);
                        $initials = strtoupper($name_parts[0][0] . $name_parts[1][0]);
                        $_SESSION['admin_initials'] = $initials; // Store initials in session

                        // Redirect to the dashboard
                        header("Location: admin.php");
                        exit();
                    } else {
                        // Incorrect password
                        $message = 'Incorrect password. Please try again.';
                    }
                } else {
                    // If the user is neither admin nor superadmin
                    $message = 'You are not authorized to access this section.';
                }
            } else {
                // Admin status is not approved
                $message = 'Your account is not yet approved. Please contact DTCE Technical Team.';
            }
        } else {
            // Email not found
            $message = 'No account found with that email address.';
        }
    } else {
        // Handle the case where email or password is not set
        $message = 'Email and password are required.';
    }
}
?>





<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Login</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="imagesconf/icon2.png" rel="shortcut icon">
    <style>
    /* Ensure no horizontal scrollbar */
    body,
    html {
        margin: 0;
        padding: 0;
        overflow-x: hidden;
        height: 100%;
    }

    .auth-login-bg {
        display: flex;
        min-height: 100vh;
    }

    /* Left side (logo & text) styling */
    .logo-column {
        background-color: #0d6efd;
        color: white;
        display: flex;
        justify-content: center;
        align-items: center;
        padding: 2rem;
        width: 72%;
        /* Left side larger (65%) */
        flex-shrink: 0;
        /* Prevent shrinking */
        flex-direction: column;
    }

    /* Center the logo and text */
    .logo-column div {
        text-align: center;
    }

    .logo-column img {
        max-width: 3200px;
        /* Slightly larger logo */
        margin-bottom: 1rem;
    }

    .logo-column h2 {
        font-size: 3.5rem;
        /* Increased font size */
        font-weight: 700;
        /* Increased font weight */
        line-height: 1.2;
    }

    .logo-column span {
        font-size: 1.9rem;
        /* Increased font size for span */
        font-weight: 600;
    }

    /* Right side (form) styling */
    .form-column {
        background-color: #fff;
        padding: 2rem;
        border-radius: 8px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        width: 35%;
        /* Right side smaller (35%) */
        display: flex;
        flex-direction: column;
        justify-content: center;
        align-items: center;
    }

    /* Adjust form field width */
    .form-column form {
        width: 100%;
    }

    .form-control {
        font-size: 1.2rem;
        padding: 1rem;
    }

    .btn {
        font-size: 1.2rem;
        padding: 1rem;
    }

    .form-column h3 {
        font-size: 2rem;
        margin-bottom: 1rem;
    }

    .form-column p {
        font-size: 1.2rem;
        margin-bottom: 2rem;
    }

    .form-label {
        font-size: 1.1rem;
    }

    .text-primary {
        font-size: 1.1rem;
    }

    /* Flexbox for the "Don't have an account?" and "Create an account" */
    .account-info {
        display: flex;
        justify-content: center;
        align-items: center;
        gap: 8px;
        /* Adjust the space between the elements */
    }

    .account-info p {
        margin-bottom: 0;
    }

    /* Responsive adjustments */
    @media (max-width: 991px) {
        .auth-login-bg {
            flex-direction: column;
        }

        .logo-column,
        .form-column {
            width: 100%;
        }
    }

    /*=== MEDIA QUERY ===*/
    @import url("https://fonts.googleapis.com/css?family=Montserrat:300,400,500,600,700|Roboto:300,400,500,700");

    html {
        font-size: 16px;
    }

    body {
        font-family: "Roboto", sans-serif;
        -webkit-font-smoothing: antialiased;
        scroll-behavior: smooth;
    }

    h1,
    h2,
    h3,
    h4,
    h5,
    h6 {
        font-family: "Montserrat", sans-serif;
        color: #222222;
        font-weight: 600;
    }

    html {
        scroll-behavior: smooth;
    }

    body,
    html {
        margin: 0;
        padding: 0;
        box-sizing: border-box;
    }

    /* Toast container styling */
    .toast {
        position: fixed;
        top: 1rem;
        /* Position at the top */
        right: 1rem;
        /* Position at the right */
        display: flex;
        align-items: center;
        background-color: #fff;
        border-radius: 0.5rem;
        box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        width: 300px;
        padding: 1rem;
        opacity: 0;
        visibility: hidden;
        transition: opacity 0.5s, visibility 0.5s;
        z-index: 9999;
        /* Ensure it's on top of other content */
    }

    /* Error toast styling */
    .toast-error {
        border-left: 4px solid #dc3545;
    }

    /* Toast icon styling */
    .toast-icon {
        margin-right: 0.75rem;
    }

    /* Toast body styling */
    .toast-body {
        flex: 1;
    }

    /* Close button styling */
    .toast-close-button {
        background: none;
        border: none;
        cursor: pointer;
        padding: 0;
        margin-left: 0.75rem;
    }

    /* Progress bar styling */
    .toast-progress-bar {
        position: absolute;
        bottom: 0;
        left: 0;
        height: 4px;
        background-color: #dc3545;
        width: 100%;
        transition: width 5s linear;
    }

    /* Animation for showing toast */
    .toast.show {
        opacity: 1;
        visibility: visible;
    }

    /* Animation for hiding toast */
    .toast.hide {
        opacity: 0;
        visibility: hidden;
    }
    </style>
</head>

<body>
    <div class="auth-login-bg">
        <!-- Branding Column -->
        <div class="logo-column">
            <div>
                <img src="imagesconf/11th.png" alt="Logo">
                <h2 style="color:white;">ANNUAL JUNIOR CHURCH <br> CO-ORDINATORS CONFERENCE <br>
                    <span style="color:white;">DIRECTORATE OF TEENS AND CHILDREN EDUCATION</span>
                </h2>
            </div>
        </div>
        <!-- Login Form Column -->
        <div class="form-column">
            <h3>Welcome back</h3>
            <p>Administrator Dashboard</p>
            <?php echo $message; ?>
            <!-- Display the feedback message -->
            <form action="admin_login.php" method="POST">
    <div class="mb-3">
        <label for="user_type" class="form-label">Role Permission</label>
        <select class="form-control" id="user_type" name="user_type" required>
            <option value="" disabled selected>Select your Role Permission</option>
            <option value="admin">Admin</option>
            <option value="superadmin">Superadmin</option>
        </select>
    </div>
    <div class="mb-3">
        <label for="email" class="form-label">Email Address</label>
        <input type="email" class="form-control" id="email" name="email" placeholder="Enter your email" required>
    </div>
    <div class="mb-4">
        <label for="password" class="form-label">Password</label>
        <input type="password" class="form-control" id="password" name="password" placeholder="Enter your password" required>
    </div>
    <div class="d-flex align-items-center justify-content-between mb-4">
        <a class="text-primary" href="admin_forgot_password.php">Forgot Password?</a>
    </div>
    <button type="submit" class="btn btn-primary w-100 py-2 mb-4 rounded">Sign In</button>
    <div class="account-info">
        <p>Don't have an account?</p>
        <a class="text-primary" href="admin_register.php">Create an account</a>
    </div>
</form>

    </div>
    <!-- Toast Container -->
    <div id="toast" class="toast">
        <div class="toast-icon">
            <!-- Error icon SVG -->
            <svg viewBox="0 0 24 24" width="24" height="24" fill="currentColor">
                <path
                    d="M11.983 0a12.206 12.206 0 00-8.51 3.653A11.8 11.8 0 000 12.207 11.779 11.779 0 0011.8 24h.214A12.111 12.111 0 0024 11.791 11.766 11.766 0 0011.983 0zM10.5 16.542a1.476 1.476 0 011.449-1.53h.027a1.527 1.527 0 011.523 1.47 1.475 1.475 0 01-1.449 1.53h-.027a1.529 1.529 0 01-1.523-1.47zM11 12.5v-6a1 1 0 012 0v6a1 1 0 11-2 0z">
                </path>
            </svg>
        </div>
        <div class="toast-body" id="toast-message">
            <!-- Message will be set by JavaScript -->
        </div>
        <button class="toast-close-button" aria-label="Close">
            <!-- Close icon SVG -->
            <svg aria-hidden="true" viewBox="0 0 14 16" width="14" height="16">
                <path fill-rule="evenodd"
                    d="M7.71 8.23l3.75 3.75-1.48 1.48-3.75-3.75-3.75 3.75L1 11.98l3.75-3.75L1 4.48 2.48 3l3.75 3.75L9.98 3l1.48 1.48-3.75 3.75z">
                </path>
            </svg>
        </button>
        <div class="toast-progress-bar"></div>
    </div>


    <!-- Bootstrap JS and dependencies -->
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
    <script>
    document.addEventListener("DOMContentLoaded", function() {
        const toast = document.getElementById("toast");
        const closeButton = toast.querySelector(".toast-close-button");
        const progressBar = toast.querySelector(".toast-progress-bar");
        const messageElement = document.getElementById("toast-message");

        // Show toast
        function showToast(type, message) {
            toast.classList.remove("toast-error", "toast-warning", "toast-success");
            if (type === "error") {
                toast.classList.add("toast-error");
            } else if (type === "warning") {
                toast.classList.add("toast-warning");
            } else if (type === "success") {
                toast.classList.add("toast-success");
            }
            messageElement.textContent = message;
            toast.classList.add("show");
            progressBar.style.width = "0%";
            setTimeout(() => {
                progressBar.style.width = "100%";
            }, 100);
        }

        // Hide toast
        function hideToast() {
            toast.classList.remove("show");
            toast.classList.add("hide");
        }

        // Close button event listener
        closeButton.addEventListener("click", hideToast);

        // Automatically hide the toast after 5 seconds
        setTimeout(hideToast, 5000);

        // Display message if present
        <?php if (!empty($message)) {
            echo 'showToast("error", ' . json_encode($message) . ');';
        } ?>
    });
    </script>

</body>

</html>