<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

session_start(); // Start the session

// Check if the admin is logged in
if (!isset($_SESSION['admin_id'])) {
    // If not logged in, redirect to the login page
    header("Location: admin_login.php");
    exit();
}

// Retrieve admin details from session variables
$admin_name = $_SESSION['admin_name'];
$admin_email = $_SESSION['admin_email'];
$admin_initials = $_SESSION['admin_initials'];
// Database connection
require 'conn.php'; // Adjust the path as necessary

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $mainHeading = $_POST['main_heading'];
    $editionHeading = $_POST['edition_heading'];
    $themeHeading = $_POST['theme_heading'];
    $dateHeading = $_POST['date_heading'];
    $registerButtonText = $_POST['register_button_text'];
    $registerButtonUrl = $_POST['register_button_url'];
    $loginButtonText = $_POST['login_button_text'];
    $loginButtonUrl = $_POST['login_button_url'];
    $bannerImage = $_FILES['banner_image']['name'];

    // Handle file upload
    if ($bannerImage) {
        $targetDir = "imagesconf/background/"; // Make sure this directory exists and is writable
        $targetFile = $targetDir . basename($bannerImage);
        move_uploaded_file($_FILES['banner_image']['tmp_name'], $targetFile);
    } else {
        // If no file was uploaded, use the existing image
        $query = "SELECT banner_image FROM main_header LIMIT 1";
        $stmt = $conn->prepare($query);
        $stmt->execute();
        $headerData = $stmt->fetch(PDO::FETCH_ASSOC);
        $bannerImage = $headerData['banner_image'];
    }

    // Update query
    $query = "UPDATE main_header SET
        main_heading = :main_heading,
        edition_heading = :edition_heading,
        theme_heading = :theme_heading,
        date_heading = :date_heading,
        register_button_text = :register_button_text,
        register_button_url = :register_button_url,
        login_button_text = :login_button_text,
        login_button_url = :login_button_url,
        banner_image = :banner_image
        WHERE id = 1"; // Assuming you have a single row

    $stmt = $conn->prepare($query);
    $stmt->execute([
        ':main_heading' => $mainHeading,
        ':edition_heading' => $editionHeading,
        ':theme_heading' => $themeHeading,
        ':date_heading' => $dateHeading,
        ':register_button_text' => $registerButtonText,
        ':register_button_url' => $registerButtonUrl,
        ':login_button_text' => $loginButtonText,
        ':login_button_url' => $loginButtonUrl,
        ':banner_image' => $bannerImage
    ]);

    // Redirect or show a success message
    header('Location: admin_main_header.php'); // Adjust as necessary
    exit;
}

// Fetch data from the database
$query = "SELECT * FROM main_header LIMIT 1";
$stmt = $conn->prepare($query);
$stmt->execute();
$headerData = $stmt->fetch(PDO::FETCH_ASSOC);

// Set default values
$mainHeading = !empty($headerData['main_heading']) ? htmlspecialchars($headerData['main_heading']) : '2024 ANNUAL RCCG JUNIOR CHURCH CO-ORDINATORS CONFERENCE';
$editionHeading = !empty($headerData['edition_heading']) ? $headerData['edition_heading'] : '11<sup>TH</sup> EDITION'; // Allow raw HTML
$themeHeading = !empty($headerData['theme_heading']) ? htmlspecialchars($headerData['theme_heading']) : 'Theme: Be Prepared (Matthew 25 : 1-13)';
$dateHeading = !empty($headerData['date_heading']) ? htmlspecialchars($headerData['date_heading']) : 'Date: Thursday 3rd - Saturday 5th October 2024';
$registerButtonText = !empty($headerData['register_button_text']) ? htmlspecialchars($headerData['register_button_text']) : 'Register Now';
$registerButtonUrl = !empty($headerData['register_button_url']) ? htmlspecialchars($headerData['register_button_url']) : '#';
$loginButtonText = !empty($headerData['login_button_text']) ? htmlspecialchars($headerData['login_button_text']) : 'Login';
$loginButtonUrl = !empty($headerData['login_button_url']) ? htmlspecialchars($headerData['login_button_url']) : '#';
$bannerImage = !empty($headerData['banner_image']) ? htmlspecialchars($headerData['banner_image']) : 'imagesconf/background/12.jpg'; // Adjust default path

?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard</title>
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css" rel="stylesheet">
    <link href="imagesconf/icon2.png" rel="shortcut icon">
    <style>
    body {
        font-family: Arial, sans-serif;
        background-color: #f8f9fa;
    }

    .navbar {
        background-color: #343a40;
    }

    .navbar-brand {
        color: #fff;
        font-weight: bold;
    }

    .sidebar {
        height: 100vh;
        background-color: #343a40;
        padding-top: 20px;
    }

    .sidebar a {
        color: #ddd;
        padding: 15px;
        display: block;
        font-size: 16px;
        text-decoration: none;
    }

    .sidebar a:hover {
        background-color: #495057;
        color: #fff;
    }

    .content {
        padding: 20px;
        margin-left: 250px;
    }

    .card-header {
        background-color: #186F45;
        color: white;
        text-align: center;
    }

    .btn-primary {
        background-color: #186F45;
        border-color: #186F45;
    }

    .btn-primary:hover {
        background-color: #145536;
        border-color: #145536;
    }

    .content {
        padding: 20px;
    }

    .card {
        border: none;
        border-radius: 10px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
    }

    .card-header {
        background-color: black;
        border-bottom: 1px solid #dee2e6;
        border-top-left-radius: 10px;
        border-top-right-radius: 10px;
        padding: 15px;
    }

    .card-body {
        padding: 20px;
    }

    .table img {
        max-width: 100px;
        height: auto;
    }

    .btn-block {
        width: 100%;
    }

    .profile-image {
        display: inline-block;
        width: 40px;
        height: 40px;
        background-color: #007bff;
        color: #fff;
        text-align: center;
        line-height: 40px;
        border-radius: 50%;
        font-weight: bold;
        margin-right: 10px;
    }

    .profile-image span {
        font-size: 16px;
        text-transform: uppercase;
    }
    </style>
</head>

<body>

    <!-- Navbar -->
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">Admin Dashboard</a>
        <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
            aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav ml-auto">
                <!-- Profile Image (Initials) -->
                <li class="nav-item">
                    <div class="profile-image">
                        <span><?php echo $_SESSION['admin_initials']; ?></span>
                    </div>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#"><i class="fas fa-user-circle"></i> Profile</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="logout.php"><i class="fas fa-sign-out-alt"></i> Logout</a>
                </li>
            </ul>
        </div>
    </nav>
     <!-- Sidebar -->
     <div class="d-flex">
    <div class="sidebar">
        <a href="admin_main_header.php"><i class="fas fa-bookmark"></i> Add Main Header</a>

        <?php if ($_SESSION['user_type'] == 'superadmin') : ?>
            <!-- Show Approve Admins only for superadmin -->
            <a href="admin_approval.php"><i class="fas fa-book"></i> Approve Admins</a>
        <?php endif; ?>

        <!-- Show all other menus for both admin and superadmin -->
        <a href="about_admin.php"><i class="fas fa-tachometer-alt"></i> Add About</a>
        <a href="admin.php"><i class="fas fa-tachometer-alt"></i> Add Speakers</a>
        <a href="manage_speakers.php"><i class="fas fa-user"></i> Manage Speakers</a>
        <a href="manage_registrants.php"><i class="fas fa-user"></i> Manage Registrants</a>
        <a href="admin_schedules.php"><i class="fas fa-calendar"></i> Manage Event Schedule</a>
        <a href="admin_upload.php"><i class="fas fa-camera"></i> Add Gallery</a>
        <a href="confgallery.php"><i class="fas fa-camera"></i> Manage Gallery</a>
        <a href="admin_sponsors.php"><i class="fas fa-user"></i> Manage Sponsors</a>
        <a href="manage_sponsors.php"><i class="fas fa-briefcase"></i> List of Sponsors</a>
        <a href="admin_news.php"><i class="fas fa-book"></i> Manage News</a>
        <a href="price_table.php"><i class="fas fa-table"></i> Manage Price Table</a>
        <a href="zoom.php"><i class="fas fa-video"></i> Add Zoom Link</a>
        <a href="#"><i class="fas fa-cog"></i> Settings</a>
        <a href="#"><i class="fas fa-question-circle"></i> Help</a>
    </div>


        <!-- Admin Details Section -->
        <div class="container mt-5 flex-grow-1">
            <div class="card">
                <div class="card-header">
                    Admin Details
                </div>
                <div class="card-body">
                    <h2>Welcome, <?php echo $admin_name; ?></h2>
                    <p>Email: <?php echo $admin_email; ?></p>
                    <p>Initials: <?php echo $admin_initials; ?></p>
                </div>
            </div>

            <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">
            <img src="imagesconf/11th.png" alt="Logo">
        </a>
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
                <a class="nav-link btn btn-secondary" href="admin.php">Back to Dashboard</a>
            </li>
        </ul>
    </nav>


        <!----Addd Content----->
        <h3>Edit Main Header</h3>
        <form method="post" enctype="multipart/form-data">
    <div class="form-group">
        <label for="main_heading">Main Heading</label>
        <input type="text" id="main_heading" name="main_heading" class="form-control" value="<?= $mainHeading ?>">
    </div>
    <div class="form-group">
        <label for="edition_heading">Edition Heading</label>
        <input type="text" id="edition_heading" name="edition_heading" class="form-control" value="<?= $editionHeading ?>">
    </div>
    <div class="form-group">
        <label for="theme_heading">Theme Heading</label>
        <input type="text" id="theme_heading" name="theme_heading" class="form-control" value="<?= $themeHeading ?>">
    </div>
    <div class="form-group">
        <label for="date_heading">Date Heading</label>
        <input type="text" id="date_heading" name="date_heading" class="form-control" value="<?= $dateHeading ?>">
    </div>
    <div class="form-group">
        <label for="register_button_text">Register Button Text</label>
        <input type="text" id="register_button_text" name="register_button_text" class="form-control" value="<?= $registerButtonText ?>">
    </div>
    <div class="form-group">
        <label for="register_button_url">Register Button URL</label>
        <input type="text" id="register_button_url" name="register_button_url" class="form-control" value="<?= $registerButtonUrl ?>">
    </div>
    <div class="form-group">
        <label for="login_button_text">Login Button Text</label>
        <input type="text" id="login_button_text" name="login_button_text" class="form-control" value="<?= $loginButtonText ?>">
    </div>
    <div class="form-group">
        <label for="login_button_url">Login Button URL</label>
        <input type="text" id="login_button_url" name="login_button_url" class="form-control" value="<?= $loginButtonUrl ?>">
    </div>
    <div class="form-group">
        <label for="banner_image">Background Image</label>
        <input type="file" id="banner_image" name="banner_image" class="form-control">
        <br>
        <?php if ($bannerImage): ?>
            <img src="<?= $bannerImage ?>" alt="Background Image" style="max-width: 300px;">
        <?php endif; ?>
    </div>
    <button type="submit" class="btn btn-primary">Save Changes</button>
</form>

        <!-- Bootstrap and FontAwesome Scripts -->
        <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
        <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.2/dist/umd/popper.min.js"></script>
        <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>

</html>