<?php
session_start(); // Start the session

// Check if the admin is logged in
if (!isset($_SESSION['admin_id'])) {
    // If not logged in, redirect to the login page
    header("Location: admin_login.php");
    exit();
}

// Retrieve admin details from session variables
$admin_name = $_SESSION['admin_name'];
$admin_email = $_SESSION['admin_email'];
$admin_initials = $_SESSION['admin_initials'];
/// Handle form submission for uploading or editing materials

include ('conn.php');
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $materialName = $_POST['material_name'];

    // Check if this is an edit request
    if (isset($_POST['material_id'])) {
        $materialId = $_POST['material_id'];

        // Update material details in the database
        $query = "UPDATE materials SET material_name = :material_name WHERE id = :id";
        $stmt = $conn->prepare($query);
        $stmt->execute([
            ':material_name' => $materialName,
            ':id' => $materialId
        ]);

        // Handle image update
        if (isset($_FILES['material_image']) && !empty($_FILES['material_image']['name'])) {
            $imageFile = $_FILES['material_image'];
            $imageFileName = basename($imageFile['name']);
            $imageFilePath = 'materials/' . $imageFileName;
            move_uploaded_file($imageFile['tmp_name'], $imageFilePath);

            // Update image path in the database
            $query = "UPDATE materials SET image_path = :image_path WHERE id = :id";
            $stmt = $conn->prepare($query);
            $stmt->execute([
                ':image_path' => $imageFileName,
                ':id' => $materialId
            ]);
        }

        // Handle PDF update
        if (isset($_FILES['material_pdf']) && !empty($_FILES['material_pdf']['name'])) {
            $pdfFile = $_FILES['material_pdf'];
            $pdfFileName = basename($pdfFile['name']);
            $pdfFilePath = 'materials/' . $pdfFileName;
            move_uploaded_file($pdfFile['tmp_name'], $pdfFilePath);

            // Update PDF path in the database
            $query = "UPDATE materials SET download_link = :download_link WHERE id = :id";
            $stmt = $conn->prepare($query);
            $stmt->execute([
                ':download_link' => $pdfFileName,
                ':id' => $materialId
            ]);
        }

        echo "<script>alert('Material updated successfully!');</script>";
    } else {
        // Handle new material upload
        if (isset($_FILES['material_image']) && isset($_FILES['material_pdf'])) {
            // Handle Image Upload
            $imageFile = $_FILES['material_image'];
            $imageFileName = basename($imageFile['name']);
            $imageFilePath = 'materials/' . $imageFileName;
            move_uploaded_file($imageFile['tmp_name'], $imageFilePath);

            // Handle PDF Upload
            $pdfFile = $_FILES['material_pdf'];
            $pdfFileName = basename($pdfFile['name']);
            $pdfFilePath = 'materials/' . $pdfFileName;
            move_uploaded_file($pdfFile['tmp_name'], $pdfFilePath);

            // Insert material details into the database
            $query = "INSERT INTO materials (material_name, image_path, download_link) VALUES (:material_name, :image_path, :download_link)";
            $stmt = $conn->prepare($query);
            $stmt->execute([
                ':material_name' => $materialName,
                ':image_path' => $imageFileName,
                ':download_link' => $pdfFileName
            ]);

            echo "<script>alert('Material uploaded successfully!');</script>";
        } else {
            echo "<script>alert('Please upload both image and PDF.');</script>";
        }
    }
}

// Handle material deletion
if (isset($_GET['delete_id'])) {
    $deleteId = $_GET['delete_id'];

    // Delete material from the database
    $query = "DELETE FROM materials WHERE id = :id";
    $stmt = $conn->prepare($query);
    $stmt->execute([':id' => $deleteId]);

    echo "<script>alert('Material deleted successfully!');</script>";
}

// Fetch all materials for viewing
$query = "SELECT * FROM materials";
$stmt = $conn->prepare($query);
$stmt->execute();
$materials = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard</title>
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css" rel="stylesheet">
    <link href="imagesconf/icon2.png" rel="shortcut icon">
    <style>
    body {
        font-family: Arial, sans-serif;
        background-color: #f8f9fa;
    }

    .navbar {
        background-color: #343a40;
    }

    .navbar-brand {
        color: #fff;
        font-weight: bold;
    }

    .sidebar {
        height: 100vh;
        background-color: #343a40;
        padding-top: 20px;
    }

    .sidebar a {
        color: #ddd;
        padding: 15px;
        display: block;
        font-size: 16px;
        text-decoration: none;
    }

    .sidebar a:hover {
        background-color: #495057;
        color: #fff;
    }

    .content {
        padding: 20px;
        margin-left: 250px;
    }

    .card-header {
        background-color: #186F45;
        color: white;
        text-align: center;
    }

    .btn-primary {
        background-color: #186F45;
        border-color: #186F45;
    }

    .btn-primary:hover {
        background-color: #145536;
        border-color: #145536;
    }

    .content {
        padding: 20px;
    }

    .card {
        border: none;
        border-radius: 10px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
    }

    .card-header {
        background-color: black;
        border-bottom: 1px solid #dee2e6;
        border-top-left-radius: 10px;
        border-top-right-radius: 10px;
        padding: 15px;
    }

    .card-body {
        padding: 20px;
    }

    .table img {
        max-width: 100px;
        height: auto;
    }

    .btn-block {
        width: 100%;
    }

    .profile-image {
        display: inline-block;
        width: 40px;
        height: 40px;
        background-color: #007bff;
        color: #fff;
        text-align: center;
        line-height: 40px;
        border-radius: 50%;
        font-weight: bold;
        margin-right: 10px;
    }

    .profile-image span {
        font-size: 16px;
        text-transform: uppercase;
    }
    </style>
</head>

<body>

    <!-- Navbar -->
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">Admin Dashboard</a>
        <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
            aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav ml-auto">
                <!-- Profile Image (Initials) -->
                <li class="nav-item">
                    <div class="profile-image">
                        <span><?php echo $_SESSION['admin_initials']; ?></span>
                    </div>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#"><i class="fas fa-user-circle"></i> Profile</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="logout.php"><i class="fas fa-sign-out-alt"></i> Logout</a>
                </li>
            </ul>
        </div>
    </nav>
     <!-- Sidebar -->
     <div class="d-flex">
    <div class="sidebar">
        <a href="admin_main_header.php"><i class="fas fa-bookmark"></i> Add Main Header</a>

        <?php if ($_SESSION['user_type'] == 'superadmin') : ?>
            <!-- Show Approve Admins only for superadmin -->
            <a href="admin_approval.php"><i class="fas fa-book"></i> Approve Admins</a>
        <?php endif; ?>

        <!-- Show all other menus for both admin and superadmin -->
        <a href="about_admin.php"><i class="fas fa-tachometer-alt"></i> Add About</a>
        <a href="admin.php"><i class="fas fa-tachometer-alt"></i> Add Speakers</a>
        <a href="manage_speakers.php"><i class="fas fa-user"></i> Manage Speakers</a>
        <a href="manage_registrants.php"><i class="fas fa-user"></i> Manage Registrants</a>
        <a href="admin_schedules.php"><i class="fas fa-calendar"></i> Manage Event Schedule</a>
        <a href="admin_upload.php"><i class="fas fa-camera"></i> Add Gallery</a>
        <a href="confgallery.php"><i class="fas fa-camera"></i> Manage Gallery</a>
        <a href="admin_sponsors.php"><i class="fas fa-user"></i> Manage Sponsors</a>
        <a href="manage_sponsors.php"><i class="fas fa-briefcase"></i> List of Sponsors</a>
        <a href="admin_news.php"><i class="fas fa-book"></i> Manage News</a>
        <a href="price_table.php"><i class="fas fa-table"></i> Manage Price Table</a>
        <a href="zoom.php"><i class="fas fa-video"></i> Add Zoom Link</a>
        <a href="#"><i class="fas fa-cog"></i> Settings</a>
        <a href="#"><i class="fas fa-question-circle"></i> Help</a>
    </div>


        <!-- Admin Details Section -->
        <div class="container mt-5 flex-grow-1">
            <div class="card">
                <div class="card-header">
                    Admin Details
                </div>
                <div class="card-body">
                    <h2>Welcome, <?php echo $admin_name; ?></h2>
                    <p>Email: <?php echo $admin_email; ?></p>
                    <p>Initials: <?php echo $admin_initials; ?></p>
                </div>
            </div>

            <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">
            <img src="imagesconf/11th.png" alt="Logo">
        </a>
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
                <a class="nav-link btn btn-secondary" href="admin.php">Back to Dashboard</a>
            </li>
        </ul>
    </nav>

        <!----Addd Content----->
        <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">
            <img src="imagesconf/11th.png" alt="Logo">
        </a>
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
                <a class="nav-link btn btn-secondary" href="admin.php">Back to Dashboard</a>
            </li>
        </ul>
    </nav>

    <div class="container mt-5">
        <div class="card mb-4">
            <div class="card-header">
                <h2 class="text-center mb-4">Upload Conference Materials</h2>
            </div>
            <div class="card-body">
                <form action="" method="POST" enctype="multipart/form-data">
                    <div class="form-group">
                        <label for="material_name">Material Name</label>
                        <input type="text" class="form-control" id="material_name" name="material_name" required>
                    </div>
                    <div class="form-group">
                        <label for="material_image">Material Image</label>
                        <input type="file" class="form-control-file" id="material_image" name="material_image" accept="image/*" required>
                    </div>
                    <div class="form-group">
                        <label for="material_pdf">Material PDF</label>
                        <input type="file" class="form-control-file" id="material_pdf" name="material_pdf" accept="application/pdf" required>
                    </div>
                    <button type="submit" class="btn btn-primary btn-block">Upload Material</button>
                </form>
            </div>
        </div>

        <!-- Display all materials -->
        <div class="card">
            <div class="card-header">
                <h2 class="text-center">Manage Materials</h2>
            </div>
            <div class="card-body">
                <table class="table table-striped table-dark">
                    <thead>
                        <tr>
                            <th>Material Name</th>
                            <th>Image</th>
                            <th>Download PDF</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($materials as $material): ?>
                            <tr>
                                <td><?= htmlspecialchars($material['material_name']) ?></td>
                                <td><img src="materials/<?= htmlspecialchars($material['image_path']) ?>" alt="Material Image" style="width: 50px;"></td>
                                <td><a href="materials/<?= htmlspecialchars($material['download_link']) ?>" class="btn btn-primary" download>Download</a></td>
                                <td>
                                    <a href="admin_edit_material.php?id=<?= $material['id'] ?>" class="btn btn-warning">Edit</a>
                                    <a href="?delete_id=<?= $material['id'] ?>" class="btn btn-danger" onclick="return confirm('Are you sure you want to delete this material?')">Delete</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
        <!-- Bootstrap and FontAwesome Scripts -->
        <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
        <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.2/dist/umd/popper.min.js"></script>
        <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>

</html>