<?php
session_start(); // Start the session

// Check if the admin is logged in
if (!isset($_SESSION['admin_id'])) {
    // If not logged in, redirect to the login page
    header("Location: admin_login.php");
    exit();
}

// Retrieve admin details from session variables
$admin_name = $_SESSION['admin_name'];
$admin_email = $_SESSION['admin_email'];
$admin_initials = $_SESSION['admin_initials'];

include 'conn.php'; // Database connection

// Initialize variables
$searchTerm = '';
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$newsPerPage = 6;
$offset = ($page - 1) * $newsPerPage;

// Handle posting news
if (isset($_POST['post_news'])) {
    $title = $_POST['title'];
    $image = $_FILES['image'];
    $post_date = $_POST['post_date'];
    $posted_by = !empty($_POST['posted_by']) ? $_POST['posted_by'] : 'DTCE';
    $content = $_POST['content'];
    
    // Handle image upload
    $imagePath = 'imagesconf/news/' . basename($image['name']);
    if (move_uploaded_file($image['tmp_name'], $imagePath)) {
        $query = "INSERT INTO confnews (title, summary, content, image_path, posted_by, date_posted, views, comments_count,comments) VALUES (:title, :summary, :content, :image_path, :posted_by, :date_posted, 0, 0, 'No Comment yet')";
        $stmt = $conn->prepare($query);
        $stmt->bindValue(':title', $title);
        $stmt->bindValue(':summary', substr($content, 0, 150));
        $stmt->bindValue(':content', $content);
        $stmt->bindValue(':image_path', $imagePath);
        $stmt->bindValue(':posted_by', $posted_by);
        $stmt->bindValue(':date_posted', $post_date);
        $stmt->execute();
    }
}

// Handle updating news
if (isset($_POST['update_news'])) {
    $newsId = $_POST['news_id'];
    $title = $_POST['title'];
    $content = $_POST['content'];
    
    $query = "UPDATE confnews SET title = :title, content = :content WHERE id = :id";
    $stmt = $conn->prepare($query);
    $stmt->bindValue(':title', $title);
    $stmt->bindValue(':content', $content);
    $stmt->bindValue(':id', $newsId);
    $stmt->execute();
}

// Handle deleting news
if (isset($_POST['delete_news'])) {
    $newsId = $_POST['news_id'];
    
    // Optionally, delete associated image if needed
    $query = "SELECT image_path FROM confnews WHERE id = :id";
    $stmt = $conn->prepare($query);
    $stmt->bindValue(':id', $newsId);
    $stmt->execute();
    $imagePath = $stmt->fetchColumn();
    
    if ($imagePath && file_exists($imagePath)) {
        unlink($imagePath);
    }
    
    $query = "DELETE FROM confnews WHERE id = :id";
    $stmt = $conn->prepare($query);
    $stmt->bindValue(':id', $newsId);
    $stmt->execute();
}
// Handle fetching news details
if (isset($_POST['fetch_news_id'])) {
    $newsId = $_POST['fetch_news_id'];
    
    $query = "SELECT id, title, content,comments FROM confnews WHERE id = :id";
    $stmt = $conn->prepare($query);
    $stmt->bindValue(':id', $newsId);
    $stmt->execute();
    $news = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if ($news) {
        echo json_encode($news);
    } else {
        echo json_encode([]);
    }
    exit();
}

// Search functionality
if (isset($_GET['search'])) {
    $searchTerm = $_GET['search'];
    $query = "SELECT id, title, summary, content, image_path, posted_by, date_posted, views, comments_count,comments FROM confnews WHERE title LIKE :searchTerm ORDER BY date_posted DESC LIMIT :offset, :newsPerPage";
    $stmt = $conn->prepare($query);
    $stmt->bindValue(':searchTerm', '%' . $searchTerm . '%');
} else {
    $query = "SELECT id, title, summary, content, image_path, posted_by, date_posted, views, comments_count,comments FROM confnews ORDER BY date_posted DESC LIMIT :offset, :newsPerPage";
    $stmt = $conn->prepare($query);
}
$stmt->bindValue(':offset', $offset, PDO::PARAM_INT);
$stmt->bindValue(':newsPerPage', $newsPerPage, PDO::PARAM_INT);
$stmt->execute();
$newsItems = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Count total number of news items for pagination
$totalQuery = "SELECT COUNT(*) AS total FROM confnews" . (isset($_GET['search']) ? " WHERE title LIKE :searchTerm" : "");
$totalStmt = $conn->prepare($totalQuery);
if (isset($_GET['search'])) {
    $totalStmt->bindValue(':searchTerm', '%' . $searchTerm . '%');
}
$totalStmt->execute();
$totalRows = $totalStmt->fetch(PDO::FETCH_ASSOC)['total'];
$totalPages = ceil($totalRows / $newsPerPage);
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard</title>
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css" rel="stylesheet">
    <link href="imagesconf/icon2.png" rel="shortcut icon">
    <style>
    body {
        font-family: Arial, sans-serif;
        background-color: #f8f9fa;
    }

    .navbar {
        background-color: #343a40;
    }

    .navbar-brand {
        color: #fff;
        font-weight: bold;
    }

    .sidebar {
        height: 100vh;
        background-color: #343a40;
        padding-top: 20px;
    }

    .sidebar a {
        color: #ddd;
        padding: 15px;
        display: block;
        font-size: 16px;
        text-decoration: none;
    }

    .sidebar a:hover {
        background-color: #495057;
        color: #fff;
    }

    .content {
        padding: 20px;
        margin-left: 250px;
    }

    .card-header {
        background-color: #186F45;
        color: white;
        text-align: center;
    }

    .btn-primary {
        background-color: #186F45;
        border-color: #186F45;
    }

    .btn-primary:hover {
        background-color: #145536;
        border-color: #145536;
    }

    .content {
        padding: 20px;
    }

    .card {
        border: none;
        border-radius: 10px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
    }

    .card-header {
        background-color: black;
        border-bottom: 1px solid #dee2e6;
        border-top-left-radius: 10px;
        border-top-right-radius: 10px;
        padding: 15px;
    }

    .card-body {
        padding: 20px;
    }

    .table img {
        max-width: 100px;
        height: auto;
    }

    .btn-block {
        width: 100%;
    }

    .profile-image {
        display: inline-block;
        width: 40px;
        height: 40px;
        background-color: #007bff;
        color: #fff;
        text-align: center;
        line-height: 40px;
        border-radius: 50%;
        font-weight: bold;
        margin-right: 10px;
    }

    .profile-image span {
        font-size: 16px;
        text-transform: uppercase;
    }

    .active-page {
        background-color: #007bff;
        color: white;
    }

    .card {
        margin-bottom: 20px;
    }

    .img-300px {

        width: 300px;
        /* Maintain aspect ratio */
        object-fit: cover;
        /* Optional: ensure the image covers the space, cutting off parts if necessary */
    }
    </style>
</head>

<body>

    <!-- Navbar -->
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">Admin Dashboard</a>
        <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
            aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav ml-auto">
                <!-- Profile Image (Initials) -->
                <li class="nav-item">
                    <div class="profile-image">
                        <span><?php echo $_SESSION['admin_initials']; ?></span>
                    </div>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#"><i class="fas fa-user-circle"></i> Profile</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="logout.php"><i class="fas fa-sign-out-alt"></i> Logout</a>
                </li>
            </ul>
        </div>
    </nav>
   <!-- Sidebar -->
   <div class="d-flex">
    <div class="sidebar">
        <a href="admin_main_header.php"><i class="fas fa-bookmark"></i> Add Main Header</a>

        <?php if ($_SESSION['user_type'] == 'superadmin') : ?>
            <!-- Show Approve Admins only for superadmin -->
            <a href="admin_approval.php"><i class="fas fa-book"></i> Approve Admins</a>
        <?php endif; ?>

        <!-- Show all other menus for both admin and superadmin -->
        <a href="about_admin.php"><i class="fas fa-tachometer-alt"></i> Add About</a>
        <a href="admin.php"><i class="fas fa-tachometer-alt"></i> Add Speakers</a>
        <a href="manage_speakers.php"><i class="fas fa-user"></i> Manage Speakers</a>
        <a href="manage_registrants.php"><i class="fas fa-user"></i> Manage Registrants</a>
        <a href="admin_schedules.php"><i class="fas fa-calendar"></i> Manage Event Schedule</a>
        <a href="admin_upload.php"><i class="fas fa-camera"></i> Add Gallery</a>
        <a href="confgallery.php"><i class="fas fa-camera"></i> Manage Gallery</a>
        <a href="admin_sponsors.php"><i class="fas fa-user"></i> Manage Sponsors</a>
        <a href="manage_sponsors.php"><i class="fas fa-briefcase"></i> List of Sponsors</a>
        <a href="admin_news.php"><i class="fas fa-book"></i> Manage News</a>
        <a href="price_table.php"><i class="fas fa-table"></i> Manage Price Table</a>
        <a href="zoom.php"><i class="fas fa-video"></i> Add Zoom Link</a>
        <a href="#"><i class="fas fa-cog"></i> Settings</a>
        <a href="#"><i class="fas fa-question-circle"></i> Help</a>
    </div>


        <!-- Admin Details Section -->
        <div class="container mt-5 flex-grow-1">
            <div class="card">
                <div class="card-header">
                    Admin Details
                </div>
                <div class="card-body">
                    <h2>Welcome, <?php echo $admin_name; ?></h2>
                    <p>Email: <?php echo $admin_email; ?></p>
                    <p>Initials: <?php echo $admin_initials; ?></p>
                </div>
            </div>

            <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">
            <img src="imagesconf/11th.png" alt="Logo">
        </a>
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
                <a class="nav-link btn btn-secondary" href="admin.php">Back to Dashboard</a>
            </li>
        </ul>
    </nav>

            <!---- Add Content ----->
            <div class="container mt-4">
                <h1>News Management</h1>

                <!-- Search Form -->
                <form method="get" class="mb-4">
                    <div class="input-group">
                        <input type="text" name="search" class="form-control" placeholder="Search news..."
                            value="<?= htmlspecialchars($searchTerm) ?>">
                        <div class="input-group-append">
                            <button class="btn btn-primary" type="submit">Search</button>
                        </div>
                    </div>
                </form>

                <!-- Create News Form -->
                <h2>Create News</h2>
                <form method="post" action="" enctype="multipart/form-data">
                    <div class="form-group">
                        <label for="title">Title</label>
                        <input type="text" class="form-control" id="title" name="title" required>
                    </div>
                    <div class="form-group">
                        <label for="image">Image</label>
                        <input type="file" class="form-control" id="image" name="image" accept="image/*" required>
                    </div>
                    <div class="form-group">
                        <label for="post_date">Post Date</label>
                        <input type="date" class="form-control" id="post_date" name="post_date" required>
                    </div>
                    <div class="form-group">
                        <label for="posted_by">Posted By</label>
                        <input type="text" class="form-control" id="posted_by" name="posted_by">
                    </div>
                    <div class="form-group">
                        <label for="content">Content</label>
                        <textarea class="form-control" id="content" name="content" rows="5" required></textarea>
                    </div>
                    <button type="submit" name="post_news" class="btn btn-primary">Post News</button>
                </form>
<br><br>
                <!-- News Items -->
                <?php if (!empty($newsItems)): ?>
    <?php foreach ($newsItems as $news): ?>
        <div class="card mb-3">
            <img src="<?= htmlspecialchars($news['image_path']) ?>" class="card-img-top img-300px" alt="<?= htmlspecialchars($news['title']) ?>">

            <div class="card-body">
                <h5 class="card-title"><?= htmlspecialchars($news['title']) ?></h5>
                <p class="card-text">
                    <small class="text-muted">Posted by <?= htmlspecialchars($news['posted_by']) ?> on <?= htmlspecialchars($news['date_posted']) ?></small>
                </p>
                <p class="card-text">
                    <?= htmlspecialchars($news['content']) ?>
                </p>
                <p class="card-text">
                    <i class="fa fa-eye"></i> <?= htmlspecialchars($news['views']) ?> views |
                    <i class="fa fa-comments"></i> <?= htmlspecialchars($news['comments_count']) ?> comments
                </p>
                
                <!-- Comments Section -->
                <div class="comments-section">
                    <h6>Comments:</h6>
                    <?php if (!empty($news['comments'])): ?>
                        <p><?= htmlspecialchars($news['comments']) ?></p>
                    <?php else: ?>
                        <p>No comments yet.</p>
                    <?php endif; ?>
                </div>
                
                <!-- Update and Delete Buttons -->
                <button type="button" class="btn btn-warning btn-update-news" data-id="<?= htmlspecialchars($news['id']) ?>">Update</button>
                <form method="post" action="" class="d-inline">
                    <input type="hidden" name="news_id" value="<?= htmlspecialchars($news['id']) ?>">
                    <button type="submit" name="delete_news" class="btn btn-danger">Delete</button>
                </form>
            </div>
        </div>
    <?php endforeach; ?>
<?php else: ?>
    <p>No news items found.</p>
<?php endif; ?>


                <!-- Pagination -->
                <nav aria-label="Page navigation">
                    <ul class="pagination">
                        <?php if ($page > 1): ?>
                        <li class="page-item"><a class="page-link"
                                href="?page=<?= $page - 1 ?>&search=<?= urlencode($searchTerm) ?>">Previous</a></li>
                        <?php endif; ?>

                        <?php for ($i = 1; $i <= $totalPages; $i++): ?>
                        <li class="page-item <?= $i === $page ? 'active' : '' ?>">
                            <a class="page-link"
                                href="?page=<?= $i ?>&search=<?= urlencode($searchTerm) ?>"><?= $i ?></a>
                        </li>
                        <?php endfor; ?>

                        <?php if ($page < $totalPages): ?>
                        <li class="page-item"><a class="page-link"
                                href="?page=<?= $page + 1 ?>&search=<?= urlencode($searchTerm) ?>">Next</a></li>
                        <?php endif; ?>
                    </ul>
                </nav>
            </div>

            <!-- Update News Modal -->
            <div class="modal fade" id="updateNewsModal" tabindex="-1" role="dialog"
                aria-labelledby="updateNewsModalLabel" aria-hidden="true">
                <div class="modal-dialog" role="document">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="updateNewsModalLabel">Update News</h5>
                            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                <span aria-hidden="true">&times;</span>
                            </button>
                        </div>
                        <div class="modal-body">
                            <form id="updateNewsForm" method="post" action="">
                                <input type="hidden" id="update-news-id" name="news_id">
                                <div class="form-group">
                                    <label for="update-title">Title</label>
                                    <input type="text" class="form-control" id="update-title" name="title" required>
                                </div>
                                <div class="form-group">
                                    <label for="update-content">Content</label>
                                    <textarea class="form-control" id="update-content" name="content" rows="5"
                                        required></textarea>
                                </div>
                                <button type="submit" name="update_news" class="btn btn-primary">Update News</button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>


            <script src="https://code.jquery.com/jquery-3.3.1.slim.min.js"></script>
            <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.7/umd/popper.min.js"></script>
            <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js"></script>
            <script>
            document.addEventListener('DOMContentLoaded', function() {
                document.querySelectorAll('.btn-update-news').forEach(button => {
                    button.addEventListener('click', function(event) {
                        event.preventDefault();

                        let newsId = this.getAttribute('data-id');

                        // Fetch news details from the server
                        fetch('admin_news.php', {
                                method: 'POST',
                                headers: {
                                    'Content-Type': 'application/x-www-form-urlencoded'
                                },
                                body: `fetch_news_id=${encodeURIComponent(newsId)}`
                            })
                            .then(response => response.json())
                            .then(data => {
                                if (data) {
                                    // Populate modal with fetched data
                                    document.querySelector('#update-news-id').value = data
                                        .id;
                                    document.querySelector('#update-title').value = data
                                        .title;
                                    document.querySelector('#update-content').value = data
                                        .content;

                                    // Show the modal
                                    $('#updateNewsModal').modal('show');
                                }
                            })
                            .catch(error => console.error('Error:', error));
                    });
                });
            });
            </script>
</body>

</html>