<?php
// Include your database connection file
include('conn.php'); // Assumes $conn is your connection variable

$message = ""; // Initialize message variable

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Capture data from the form
    $name = $_POST['name'];
    $email = $_POST['email'];
    $phone = $_POST['phone'];
    $parish = $_POST['parish'];
    $region = $_POST['region'];
    $country = $_POST['country'];
    $password = $_POST['password'];
    $confirm_password = $_POST['confirm_password'];
    $user_type = 'admin'; // Set default user type as 'admin'

    // Server-side password validation
    if (strlen($password) < 8 || 
        !preg_match('/[A-Z]/', $password) || 
        !preg_match('/[a-z]/', $password) || 
        !preg_match('/\d/', $password) || 
        !preg_match('/[\W_]/', $password)) {
        $message = '<div class="alert alert-danger" role="alert">Password must be at least 8 characters long, and contain an uppercase letter, a lowercase letter, a number, and a special character.</div>';
    } elseif ($password !== $confirm_password) {
        $message = '<div class="alert alert-danger" role="alert">Passwords do not match!</div>';
    } else {
        // If password validation passes, hash the password
        $hashed_password = password_hash($password, PASSWORD_BCRYPT); // Hash password
        $status = 'pending'; // Default status is 'pending'

        // Prepare the SQL statement
        $sql = "INSERT INTO dtceadmin (name, email, phone, parish, region, country, password, user_type, status)
                VALUES (:name, :email, :phone, :parish, :region, :country, :password, :user_type, :status)";

        // Use prepared statements to avoid SQL injection
        $stmt = $conn->prepare($sql);

        // Bind parameters
        $stmt->bindParam(':name', $name);
        $stmt->bindParam(':email', $email);
        $stmt->bindParam(':phone', $phone);
        $stmt->bindParam(':parish', $parish);
        $stmt->bindParam(':region', $region);
        $stmt->bindParam(':country', $country);
        $stmt->bindParam(':password', $hashed_password);
        $stmt->bindParam(':user_type', $user_type);
        $stmt->bindParam(':status', $status);

        // Execute the statement and set success/failure message
        if ($stmt->execute()) {
            $message = '<div class="alert alert-success" role="alert">Admin registered successfully and awaiting approval!</div>';
        } else {
            $message = '<div class="alert alert-danger" role="alert">Error registering admin. Please try again!</div>';
        }
    }
}
?>


<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Registration</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="imagesconf/icon2.png" rel="shortcut icon">
    <style>
    /* Ensure no horizontal scrollbar */
    body,
    html {
        margin: 0;
        padding: 0;
        overflow-x: hidden;
        height: 100%;
    }

    .auth-login-bg {
        display: flex;
        min-height: 100vh;
    }

    /* Left side (logo & text) styling */
    .logo-column {
        background-color: #0d6efd;
        color: white;
        display: flex;
        justify-content: center;
        align-items: center;
        padding: 2rem;
        width: 72%;
        flex-shrink: 0;
        flex-direction: column;
    }

    .logo-column div {
        text-align: center;
    }

    .logo-column img {
        max-width: 3200px;
        margin-bottom: 1rem;
    }

    .logo-column h2 {
        font-size: 3.5rem;
        font-weight: 700;
        line-height: 1.2;
    }

    .logo-column span {
        font-size: 1.9rem;
        font-weight: 600;
    }

    /* Right side (form) styling */
    .form-column {
        background-color: #fff;
        padding: 2rem;
        border-radius: 8px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        width: 35%;
        display: flex;
        flex-direction: column;
        justify-content: center;
        align-items: center;
    }

    .form-column form {
        width: 100%;
    }

    /* Adjusted form control height by reducing padding */
    .form-control {
        font-size: 1.1rem;
        padding: 0.5rem;
        /* Reduced padding */
    }

    /* Adjusted button height */
    .btn {
        font-size: 1.1rem;
        padding: 0.7rem;
        /* Reduced padding for smaller button */
    }

    .form-column h3 {
        font-size: 2rem;
        margin-bottom: 1rem;
    }

    .form-column p {
        font-size: 1.2rem;
        margin-bottom: 2rem;
    }

    .form-label {
        font-size: 1.1rem;
    }

    .text-primary {
        font-size: 1.1rem;
    }

    .account-info {
        display: flex;
        justify-content: center;
        align-items: center;
        gap: 8px;
    }

    .account-info p {
        margin-bottom: 0;
    }

    /* Responsive adjustments */
    @media (max-width: 991px) {
        .auth-login-bg {
            flex-direction: column;
        }

        .logo-column,
        .form-column {
            width: 100%;
        }
    }

    /*=== MEDIA QUERY ===*/
    @import url("https://fonts.googleapis.com/css?family=Montserrat:300,400,500,600,700|Roboto:300,400,500,700");

    html {
        font-size: 16px;
    }

    body {
        font-family: "Roboto", sans-serif;
        -webkit-font-smoothing: antialiased;
        scroll-behavior: smooth;
    }

    h1,
    h2,
    h3,
    h4,
    h5,
    h6 {
        font-family: "Montserrat", sans-serif;
        color: #222222;
        font-weight: 600;
    }

    html {
        scroll-behavior: smooth;
    }
    </style>
</head>

<body>
    <div class="auth-login-bg">
        <!-- Branding Column -->
        <div class="logo-column">
            <div>
                <img src="imagesconf/11th.png" alt="Logo">
                <h2 style="color:white;">ANNUAL JUNIOR CHURCH <br> CO-ORDINATORS CONFERENCE <br>
                    <span style="color:white;">DIRECTORATE OF TEENS AND CHILDREN EDUCATION</span>
                </h2>
            </div>
        </div>
        <!-- Registration Form Column -->
        <div class="form-column">
            <h3>Register Account</h3>
            <p>Administrator</p>
            <!-- Display the alert message here -->
            <?php echo $message; ?>
            <form action="admin_register.php" method="POST">
    <div class="mb-3">
        <label for="name" class="form-label">Name</label>
        <input class="form-control" name="name" id="name" type="text" required>
    </div>
    <div class="mb-3">
        <label for="email" class="form-label">Email Address</label>
        <input class="form-control" name="email" id="email" type="email" required>
    </div>
    <div class="mb-3">
        <label for="phone" class="form-label">Phone Number (Whatsapp)</label>
        <input class="form-control" name="phone" id="phone" type="number" required>
    </div>
    <div class="mb-3">
        <label for="parish" class="form-label">Parish</label>
        <input class="form-control" name="parish" id="parish" type="text" required>
    </div>
    <div class="mb-3">
        <label for="region" class="form-label">Region</label>
        <input class="form-control" name="region" id="region" type="text" required>
    </div>
    <div class="mb-3">
        <label for="country" class="form-label">Country</label>
        <input class="form-control" name="country" id="country" type="text" required>
    </div>
    <div class="mb-4">
        <label for="password" class="form-label">Password</label>
        <input class="form-control" id="password" type="password" name="password" required minlength="8"
            pattern="(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[\W_]).{8,}"
            title="Password must be at least 8 characters long and contain at least one uppercase letter, one lowercase letter, one number, and one special character.">
    </div>
    <div class="mb-4">
        <label for="confirm_password" class="form-label">Confirm Password</label>
        <input class="form-control" id="confirm_password" type="password" name="confirm_password" required>
    </div>
    <!-- Hidden field for user type -->
    <input type="hidden" name="user_type" value="admin">
    <div class="d-flex align-items-center justify-content-between mb-4">
        <a class="text-primary fw-medium" href="admin_login.php">Login instead?</a>
    </div>
    <button type="submit" class="btn btn-primary w-100 py-8 mb-4 rounded-2">Register</button>
</form>

    </div>
    <!-- Bootstrap JS and dependencies -->
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
    <script>
    const password = document.getElementById('password');
    const confirmPassword = document.getElementById('confirm_password');

    confirmPassword.addEventListener('input', function() {
        if (password.value !== confirmPassword.value) {
            confirmPassword.setCustomValidity("Passwords do not match!");
        } else {
            confirmPassword.setCustomValidity('');
        }
    });
    </script>
</body>

</html>