<?php
session_start(); // Start the session

// Check if the admin is logged in
if (!isset($_SESSION['admin_id'])) {
    // If not logged in, redirect to the login page
    header("Location: admin_login.php");
    exit();
}

// Retrieve admin details from session variables
$admin_name = $_SESSION['admin_name'];
$admin_email = $_SESSION['admin_email'];
$admin_initials = $_SESSION['admin_initials'];

include 'conn.php'; // Database connection

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['add_event'])) {
        // Add event
        $event_name = $_POST['event_name'];
        $schedule_date = $_POST['schedule_date'];
        $start_time = $_POST['start_time'];
        $end_time = $_POST['end_time'];
        $description = $_POST['description'];
        $venue = $_POST['venue'];
        $day_label = $_POST['day_label'];
        $activity = $_POST['activity'];
        $subject = $_POST['subject'];
        
        $stmt = $conn->prepare("INSERT INTO event_schedules (event_name, schedule_date, start_time, end_time, description, venue, day_label, activity, subject) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
        $stmt->execute([$event_name, $schedule_date, $start_time, $end_time, $description, $venue, $day_label, $activity, $subject]);
    } elseif (isset($_POST['edit_event'])) {
        // Edit event
        $id = $_POST['id'];
        $event_name = $_POST['event_name'];
        $schedule_date = $_POST['schedule_date'];
        $start_time = $_POST['start_time'];
        $end_time = $_POST['end_time'];
        $description = $_POST['description'];
        $venue = $_POST['venue'];
        $day_label = $_POST['day_label'];
        $activity = $_POST['activity'];
        $subject = $_POST['subject'];
        
        $stmt = $conn->prepare("UPDATE event_schedules SET event_name = ?, schedule_date = ?, start_time = ?, end_time = ?, description = ?, venue = ?, day_label = ?, activity = ?, subject = ? WHERE id = ?");
        $stmt->execute([$event_name, $schedule_date, $start_time, $end_time, $description, $venue, $day_label, $activity, $subject, $id]);
    } elseif (isset($_POST['delete_event'])) {
        // Delete event
        $id = $_POST['id'];
        $stmt = $conn->prepare("DELETE FROM event_schedules WHERE id = ?");
        $stmt->execute([$id]);
    }
}

// Fetch events for listing
$stmt = $conn->prepare("SELECT * FROM event_schedules ORDER BY schedule_date, start_time");
$stmt->execute();
$events = $stmt->fetchAll();
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard</title>
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css" rel="stylesheet">
    <link href="imagesconf/icon2.png" rel="shortcut icon">
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f8f9fa;
        }
        .navbar {
            background-color: #343a40;
        }
        .navbar-brand {
            color: #fff;
            font-weight: bold;
        }
        .sidebar {
            height: 100vh;
            background-color: #343a40;
            padding-top: 20px;
        }
        .sidebar a {
            color: #ddd;
            padding: 15px;
            display: block;
            font-size: 16px;
            text-decoration: none;
        }
        .sidebar a:hover {
            background-color: #495057;
            color: #fff;
        }
        .content {
            padding: 20px;
            margin-left: 250px;
        }
        .card-header {
            background-color: #186F45;
            color: white;
            text-align: center;
        }
        .btn-primary {
            background-color: #186F45;
            border-color: #186F45;
        }
        .btn-primary:hover {
            background-color: #145536;
            border-color: #145536;
        }
        .content {
            padding: 20px;
        }
        .card {
            border: none;
            border-radius: 10px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }
        .card-header {
            background-color: black;
            border-bottom: 1px solid #dee2e6;
            border-top-left-radius: 10px;
            border-top-right-radius: 10px;
            padding: 15px;
        }
        .card-body {
            padding: 20px;
        }
        .table img {
            max-width: 100px;
            height: auto;
        }
        .btn-block {
            width: 100%;
        }
        .profile-image {
    display: inline-block;
    width: 40px;
    height: 40px;
    background-color: #007bff;
    color: #fff;
    text-align: center;
    line-height: 40px;
    border-radius: 50%;
    font-weight: bold;
    margin-right: 10px;
}

.profile-image span {
    font-size: 16px;
    text-transform: uppercase;
}

    </style>
</head>
<body>

    <!-- Navbar -->
    <!-- Navbar -->
<nav class="navbar navbar-expand-lg navbar-dark">
    <a class="navbar-brand" href="#">Admin Dashboard</a>
    <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
        <span class="navbar-toggler-icon"></span>
    </button>
    <div class="collapse navbar-collapse" id="navbarNav">
        <ul class="navbar-nav ml-auto">
            <!-- Profile Image (Initials) -->
            <li class="nav-item">
                <div class="profile-image">
                    <span><?php echo $_SESSION['admin_initials']; ?></span>
                </div>
            </li>
            <li class="nav-item">
                <a class="nav-link" href="#"><i class="fas fa-user-circle"></i> Profile</a>
            </li>
            <li class="nav-item">
                <a class="nav-link" href="logout.php"><i class="fas fa-sign-out-alt"></i> Logout</a>
            </li>
        </ul>
    </div>
</nav>
 <!-- Sidebar -->
 <div class="d-flex">
    <div class="sidebar">
        <a href="admin_main_header.php"><i class="fas fa-bookmark"></i> Add Main Header</a>

        <?php if ($_SESSION['user_type'] == 'superadmin') : ?>
            <!-- Show Approve Admins only for superadmin -->
            <a href="admin_approval.php"><i class="fas fa-book"></i> Approve Admins</a>
        <?php endif; ?>

        <!-- Show all other menus for both admin and superadmin -->
        <a href="about_admin.php"><i class="fas fa-tachometer-alt"></i> Add About</a>
        <a href="admin.php"><i class="fas fa-tachometer-alt"></i> Add Speakers</a>
        <a href="manage_speakers.php"><i class="fas fa-user"></i> Manage Speakers</a>
        <a href="manage_registrants.php"><i class="fas fa-user"></i> Manage Registrants</a>
        <a href="admin_schedules.php"><i class="fas fa-calendar"></i> Manage Event Schedule</a>
        <a href="admin_upload.php"><i class="fas fa-camera"></i> Add Gallery</a>
        <a href="confgallery.php"><i class="fas fa-camera"></i> Manage Gallery</a>
        <a href="admin_sponsors.php"><i class="fas fa-user"></i> Manage Sponsors</a>
        <a href="manage_sponsors.php"><i class="fas fa-briefcase"></i> List of Sponsors</a>
        <a href="admin_news.php"><i class="fas fa-book"></i> Manage News</a>
        <a href="price_table.php"><i class="fas fa-table"></i> Manage Price Table</a>
        <a href="zoom.php"><i class="fas fa-video"></i> Add Zoom Link</a>
        <a href="#"><i class="fas fa-cog"></i> Settings</a>
        <a href="#"><i class="fas fa-question-circle"></i> Help</a>
    </div>


        <!-- Admin Details Section -->
        <div class="container mt-5 flex-grow-1">
            <div class="card">
                <div class="card-header">
                    Admin Details
                </div>
                <div class="card-body">
                    <h2>Welcome, <?php echo $admin_name; ?></h2>
                    <p>Email: <?php echo $admin_email; ?></p>
                    <p>Initials: <?php echo $admin_initials; ?></p>
                </div>
            </div>

            <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">
            <img src="imagesconf/11th.png" alt="Logo">
        </a>
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
                <a class="nav-link btn btn-secondary" href="admin.php">Back to Dashboard</a>
            </li>
        </ul>
    </nav>

       
       <!----Addd Content----->
       <div class="container mt-5">
    <h2>Manage Event Schedules</h2>
    
    <!-- Add Event Form -->
    <div class="card mb-4">
        <div class="card-header">
            Add New Event
        </div>
        <div class="card-body">
            <form method="POST" action="">
                <div class="form-group">
                    <label for="event_name">Event Name</label>
                    <input type="text" class="form-control" id="event_name" name="event_name" required>
                </div>
                <div class="form-group">
                    <label for="schedule_date">Schedule Date</label>
                    <input type="date" class="form-control" id="schedule_date" name="schedule_date" required>
                </div>
                <div class="form-group">
                    <label for="start_time">Start Time</label>
                    <input type="time" class="form-control" id="start_time" name="start_time" required>
                </div>
                <div class="form-group">
                    <label for="end_time">End Time</label>
                    <input type="time" class="form-control" id="end_time" name="end_time" required>
                </div>
                <div class="form-group">
                    <label for="description">Description</label>
                    <textarea class="form-control" id="description" name="description"></textarea>
                </div>
                <div class="form-group">
                    <label for="venue">Venue</label>
                    <input type="text" class="form-control" id="venue" name="venue" required>
                </div>
                <div class="form-group">
                    <label for="day_label">Day Label</label>
                    <input type="text" class="form-control" id="day_label" name="day_label" required>
                </div>
                <div class="form-group">
                    <label for="activity">Activity</label>
                    <input type="text" class="form-control" id="activity" name="activity" required>
                </div>
                <div class="form-group">
                    <label for="subject">Subject</label>
                    <input type="text" class="form-control" id="subject" name="subject">
                </div>
                <button type="submit" name="add_event" class="btn btn-primary">Add Event</button>
            </form>
        </div>
    </div>

    <!-- Event List -->
    <div class="card">
        <div class="card-header">
            Event List
        </div>
        <div class="card-body">
            <table class="table table-bordered">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Event Name</th>
                        <th>Schedule Date</th>
                        <th>Start Time</th>
                        <th>End Time</th>
                        <th>Description</th>
                        <th>Venue</th>
                        <th>Day Label</th>
                        <th>Activity</th>
                        <th>Subject</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($events as $event): ?>
                        <tr>
                            <td><?= htmlspecialchars($event['id']) ?></td>
                            <td><?= htmlspecialchars($event['event_name']) ?></td>
                            <td><?= htmlspecialchars($event['schedule_date']) ?></td>
                            <td><?= date('g:iA', strtotime($event['start_time'])) ?></td>
                            <td><?= date('g:iA', strtotime($event['end_time'])) ?></td>
                            <td><?= htmlspecialchars($event['description']) ?></td>
                            <td><?= htmlspecialchars($event['venue']) ?></td>
                            <td><?= htmlspecialchars($event['day_label']) ?></td>
                            <td><?= htmlspecialchars($event['activity']) ?></td>
                            <td><?= htmlspecialchars($event['subject']) ?></td>
                            <td>
                                <!-- Edit Event Button -->
                                <button class="btn btn-warning btn-sm" data-toggle="modal" data-target="#editModal" data-id="<?= htmlspecialchars($event['id']) ?>">Edit</button>
                                
                                <!-- Delete Event Button -->
                                <form method="POST" action="" style="display:inline;">
                                    <input type="hidden" name="id" value="<?= htmlspecialchars($event['id']) ?>">
                                    <button type="submit" name="delete_event" class="btn btn-danger btn-sm">Delete</button>
                                </form>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- Edit Event Modal -->
<div class="modal fade" id="editModal" tabindex="-1" role="dialog" aria-labelledby="editModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="editModalLabel">Edit Event</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <form method="POST" action="">
                    <input type="hidden" id="edit_id" name="id">
                    <div class="form-group">
                        <label for="edit_event_name">Event Name</label>
                        <input type="text" class="form-control" id="edit_event_name" name="event_name" required>
                    </div>
                    <div class="form-group">
                        <label for="edit_schedule_date">Schedule Date</label>
                        <input type="date" class="form-control" id="edit_schedule_date" name="schedule_date" required>
                    </div>
                    <div class="form-group">
                        <label for="edit_start_time">Start Time</label>
                        <input type="time" class="form-control" id="edit_start_time" name="start_time" required>
                    </div>
                    <div class="form-group">
                        <label for="edit_end_time">End Time</label>
                        <input type="time" class="form-control" id="edit_end_time" name="end_time" required>
                    </div>
                    <div class="form-group">
                        <label for="edit_description">Description</label>
                        <textarea class="form-control" id="edit_description" name="description"></textarea>
                    </div>
                    <div class="form-group">
                        <label for="edit_venue">Venue</label>
                        <input type="text" class="form-control" id="edit_venue" name="venue" required>
                    </div>
                    <div class="form-group">
                        <label for="edit_day_label">Day Label</label>
                        <input type="text" class="form-control" id="edit_day_label" name="day_label" required>
                    </div>
                    <div class="form-group">
                        <label for="edit_activity">Activity</label>
                        <input type="text" class="form-control" id="edit_activity" name="activity" required>
                    </div>
                    <div class="form-group">
                        <label for="edit_subject">Subject</label>
                        <input type="text" class="form-control" id="edit_subject" name="subject">
                    </div>
                    <button type="submit" name="edit_event" class="btn btn-primary">Update Event</button>
                </form>
            </div>
        </div>
    </div>
</div>

<script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.9.2/dist/umd/popper.min.js"></script>
<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
<script>
    $('#editModal').on('show.bs.modal', function (event) {
        var button = $(event.relatedTarget);
        var id = button.data('id');
        
        // Fetch the event data and fill the form
        $.ajax({
            url: 'fetch_event.php',
            method: 'POST',
            data: { id: id },
            dataType: 'json',
            success: function(data) {
                $('#edit_id').val(data.id);
                $('#edit_event_name').val(data.event_name);
                $('#edit_schedule_date').val(data.schedule_date);
                $('#edit_start_time').val(data.start_time);
                $('#edit_end_time').val(data.end_time);
                $('#edit_description').val(data.description);
                $('#edit_venue').val(data.venue);
                $('#edit_day_label').val(data.day_label);
                $('#edit_activity').val(data.activity);
                $('#edit_subject').val(data.subject);
            }
        });
    });
</script>
    <!-- Bootstrap and FontAwesome Scripts -->
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.2/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>
</html>
