<?php
require 'tcpdf/tcpdf.php'; // Adjust the path as necessary

// Database connection
require 'conn.php'; // Adjust the path as necessary

// Function to add suffix to day
function formatDateWithSuffix($date) {
    // Extract day, month, and year from date
    $day = date('j', strtotime($date)); // Day without leading zeros
    $month = date('F', strtotime($date)); // Full month name
    $year = date('Y', strtotime($date)); // Year

    // Determine suffix
    if ($day == 1 || $day == 21 || $day == 31) {
        $suffix = 'st';
    } elseif ($day == 2 || $day == 22) {
        $suffix = 'nd';
    } elseif ($day == 3 || $day == 23) {
        $suffix = 'rd';
    } else {
        $suffix = 'th';
    }

    // Return formatted date with suffix and comma before the year
    return $day . $suffix . ' ' . $month . ', ' . $year;
}

if (isset($_GET['id'])) {
    $participantId = intval($_GET['id']);

    // Fetch participant details
    $query = "SELECT * FROM coordconf WHERE id = :id";
    $stmt = $conn->prepare($query);
    $stmt->bindParam(':id', $participantId, PDO::PARAM_INT);
    $stmt->execute();
    $participant = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($participant) {
        // Create new PDF document
        $pdf = new TCPDF('P', 'mm', 'A4'); // 'P' for portrait orientation
        $pdf->AddPage();

        // Set background image to fit A4 page
        $pdf->Image('confcertificate.jpg', 10, 10, 216, 303, '', '', '', false, 171, '', false, false, 0, 'C', false, false);

        // Set font for participant name
        $pdf->SetFont('Helvetica', 'B', 35);
        $pdf->SetTextColor(0, 0, 0); // Set text color to black

        // Add participant name (Uppercase)
        $pdf->SetXY(7, 125); // Adjust position as necessary
        $pdf->Cell(0, 40, strtoupper($participant['fullname']), 0, 1, 'C');

        // Set font for the date
        $pdf->SetFont('Helvetica', '', 20);
        $pdf->SetXY(40, 190); // Adjust position as necessary

        // Add formatted date
        $formattedDate = formatDateWithSuffix(date('Y-m-d')); // Get current date in 'Y-m-d' format
        $pdf->Cell(0, 10, $formattedDate, 0, 1, 'C'); // Display formatted date

        // Close and output PDF document
        $pdf->Output('certificate_' . $participantId . '.pdf', 'D'); // 'D' for download
    } else {
        echo 'Participant not found.';
    }
} else {
    echo 'No participant ID specified.';
}
?>
