<?php
session_start(); // Start the session

// Check if the admin is logged in
if (!isset($_SESSION['admin_id'])) {
    // If not logged in, redirect to the login page
    header("Location: admin_login.php");
    exit();
}

// Retrieve admin details from session variables
$admin_name = $_SESSION['admin_name'];
$admin_email = $_SESSION['admin_email'];
$admin_initials = $_SESSION['admin_initials'];
// Include the database connection
include 'conn.php';

// Initialize variables
$pricingItems = [];
$editMode = false;
$editId = null;
$message = '';

// Fetch pricing data
$query = "SELECT * FROM price_table";
$stmt = $conn->prepare($query);
$stmt->execute();
$pricingItems = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Create or Update
    if (isset($_POST['save'])) {
        $title = $_POST['title'];
        $price = $_POST['price'];
        $features = $_POST['features'];
        $button_url = $_POST['button_url'];
        $button_text = $_POST['button_text'];
        $id = $_POST['id'] ?? null;

        if ($id) {
            // Update
            $query = "UPDATE price_table SET title = ?, price = ?, features = ?, button_url = ?, button_text = ? WHERE id = ?";
            $params = [$title, $price, $features, $button_url, $button_text, $id];
            $message = 'Pricing item updated successfully!';
        } else {
            // Create
            $query = "INSERT INTO price_table (title, price, features, button_url, button_text) VALUES (?, ?, ?, ?, ?)";
            $params = [$title, $price, $features, $button_url, $button_text];
            $message = 'Pricing item created successfully!';
        }
        $stmt = $conn->prepare($query);
        $stmt->execute($params);
    }

    // Delete
    if (isset($_POST['delete'])) {
        $id = $_POST['id'];
        $query = "DELETE FROM price_table WHERE id = ?";
        $stmt = $conn->prepare($query);
        $stmt->execute([$id]);
        $message = 'Pricing item deleted successfully!';
    }

    // Reload data after any changes
    $query = "SELECT * FROM price_table";
    $stmt = $conn->prepare($query);
    $stmt->execute();
    $pricingItems = $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Handle edit request
if (isset($_GET['edit'])) {
    $editId = $_GET['edit'];
    $query = "SELECT * FROM price_table WHERE id = ?";
    $stmt = $conn->prepare($query);
    $stmt->execute([$editId]);
    $editItem = $stmt->fetch(PDO::FETCH_ASSOC);
    $editMode = true;
}
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard</title>
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css" rel="stylesheet">
    <link href="imagesconf/icon2.png" rel="shortcut icon">
    <style>
    body {
        font-family: Arial, sans-serif;
        background-color: #f8f9fa;
    }

    .navbar {
        background-color: #343a40;
    }

    .navbar-brand {
        color: #fff;
        font-weight: bold;
    }

    .sidebar {
        height: 100vh;
        background-color: #343a40;
        padding-top: 20px;
    }

    .sidebar a {
        color: #ddd;
        padding: 15px;
        display: block;
        font-size: 16px;
        text-decoration: none;
    }

    .sidebar a:hover {
        background-color: #495057;
        color: #fff;
    }

    .content {
        padding: 20px;
        margin-left: 250px;
    }

    .card-header {
        background-color: #186F45;
        color: white;
        text-align: center;
    }

    .btn-primary {
        background-color: #186F45;
        border-color: #186F45;
    }

    .btn-primary:hover {
        background-color: #145536;
        border-color: #145536;
    }

    .content {
        padding: 20px;
    }

    .card {
        border: none;
        border-radius: 10px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
    }

    .card-header {
        background-color: black;
        border-bottom: 1px solid #dee2e6;
        border-top-left-radius: 10px;
        border-top-right-radius: 10px;
        padding: 15px;
    }

    .card-body {
        padding: 20px;
    }

    .table img {
        max-width: 100px;
        height: auto;
    }

    .btn-block {
        width: 100%;
    }

    .profile-image {
        display: inline-block;
        width: 40px;
        height: 40px;
        background-color: #007bff;
        color: #fff;
        text-align: center;
        line-height: 40px;
        border-radius: 50%;
        font-weight: bold;
        margin-right: 10px;
    }

    .profile-image span {
        font-size: 16px;
        text-transform: uppercase;
    }
    </style>
</head>

<body>

    <!-- Navbar -->
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">Admin Dashboard</a>
        <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
            aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav ml-auto">
                <!-- Profile Image (Initials) -->
                <li class="nav-item">
                    <div class="profile-image">
                        <span><?php echo $_SESSION['admin_initials']; ?></span>
                    </div>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#"><i class="fas fa-user-circle"></i> Profile</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="logout.php"><i class="fas fa-sign-out-alt"></i> Logout</a>
                </li>
            </ul>
        </div>
    </nav>
    <!-- Sidebar -->
    <div class="d-flex">
    <div class="sidebar">
        <a href="admin_main_header.php"><i class="fas fa-bookmark"></i> Add Main Header</a>

        <?php if ($_SESSION['user_type'] == 'superadmin') : ?>
            <!-- Show Approve Admins only for superadmin -->
            <a href="admin_approval.php"><i class="fas fa-book"></i> Approve Admins</a>
        <?php endif; ?>

        <!-- Show all other menus for both admin and superadmin -->
        <a href="about_admin.php"><i class="fas fa-tachometer-alt"></i> Add About</a>
        <a href="admin.php"><i class="fas fa-tachometer-alt"></i> Add Speakers</a>
        <a href="manage_speakers.php"><i class="fas fa-user"></i> Manage Speakers</a>
        <a href="manage_registrants.php"><i class="fas fa-user"></i> Manage Registrants</a>
        <a href="admin_schedules.php"><i class="fas fa-calendar"></i> Manage Event Schedule</a>
        <a href="admin_upload.php"><i class="fas fa-camera"></i> Add Gallery</a>
        <a href="confgallery.php"><i class="fas fa-camera"></i> Manage Gallery</a>
        <a href="admin_sponsors.php"><i class="fas fa-user"></i> Manage Sponsors</a>
        <a href="manage_sponsors.php"><i class="fas fa-briefcase"></i> List of Sponsors</a>
        <a href="admin_news.php"><i class="fas fa-book"></i> Manage News</a>
        <a href="price_table.php"><i class="fas fa-table"></i> Manage Price Table</a>
        <a href="zoom.php"><i class="fas fa-video"></i> Add Zoom Link</a>
        <a href="#"><i class="fas fa-cog"></i> Settings</a>
        <a href="#"><i class="fas fa-question-circle"></i> Help</a>
    </div>


        <!-- Admin Details Section -->
        <div class="container mt-5 flex-grow-1">
            <div class="card">
                <div class="card-header">
                    Admin Details
                </div>
                <div class="card-body">
                    <h2>Welcome, <?php echo $admin_name; ?></h2>
                    <p>Email: <?php echo $admin_email; ?></p>
                    <p>Initials: <?php echo $admin_initials; ?></p>
                </div>
            </div>

            <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">
            <img src="imagesconf/11th.png" alt="Logo">
        </a>
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
                <a class="nav-link btn btn-secondary" href="admin.php">Back to Dashboard</a>
            </li>
        </ul>
    </nav>

            <div class="container mt-4">
        <h1>Manage Pricing</h1>
        <?php if ($message): ?>
            <div class="alert alert-success"><?= htmlspecialchars($message) ?></div>
        <?php endif; ?>

        <!-- Pricing Form -->
        <div class="card mb-4">
            <div class="card-body">
                <h4 class="card-title"><?= $editMode ? 'Edit Pricing Item' : 'Add New Pricing Item' ?></h4>
                <form method="post" action="">
                    <input type="hidden" name="id" value="<?= htmlspecialchars($editItem['id'] ?? '') ?>">
                    <div class="form-group">
                        <label for="title">Title</label>
                        <input type="text" class="form-control" id="title" name="title" value="<?= htmlspecialchars($editItem['title'] ?? '') ?>" required>
                    </div>
                    <div class="form-group">
                        <label for="price">Price</label>
                        <input type="number" class="form-control" id="price" name="price" value="<?= htmlspecialchars($editItem['price'] ?? '') ?>" step="0.01" required>
                    </div>
                    <div class="form-group">
                        <label for="features">Features (comma-separated)</label>
                        <input type="text" class="form-control" id="features" name="features" value="<?= htmlspecialchars($editItem['features'] ?? '') ?>" required>
                    </div>
                    <div class="form-group">
                        <label for="button_url">Button URL</label>
                        <input type="url" class="form-control" id="button_url" name="button_url" value="<?= htmlspecialchars($editItem['button_url'] ?? '') ?>" required>
                    </div>
                    <div class="form-group">
                        <label for="button_text">Button Text</label>
                        <input type="text" class="form-control" id="button_text" name="button_text" value="<?= htmlspecialchars($editItem['button_text'] ?? '') ?>" required>
                    </div>
                    <button type="submit" name="save" class="btn btn-primary"><?= $editMode ? 'Update' : 'Save' ?></button>
                </form>
            </div>
        </div>

        <!-- Pricing List -->
        <div class="card">
            <div class="card-body">
                <h4 class="card-title">Current Pricing Items</h4>
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Title</th>
                            <th>Price</th>
                            <th>Features</th>
                            <th>Button URL</th>
                            <th>Button Text</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($pricingItems as $item): ?>
                            <tr>
                                <td><?= htmlspecialchars($item['id']) ?></td>
                                <td><?= htmlspecialchars($item['title']) ?></td>
                                <td><?= htmlspecialchars(number_format($item['price'], 2)) ?></td>
                                <td><?= htmlspecialchars($item['features']) ?></td>
                                <td><?= htmlspecialchars($item['button_url']) ?></td>
                                <td><?= htmlspecialchars($item['button_text']) ?></td>
                                <td>
                                    <a href="?edit=<?= htmlspecialchars($item['id']) ?>" class="btn btn-warning btn-sm">Edit</a>
                                    <form method="post" action="" style="display:inline;">
                                        <input type="hidden" name="id" value="<?= htmlspecialchars($item['id']) ?>">
                                        <button type="submit" name="delete" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this item?');">Delete</button>
                                    </form>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <!-- Optional JavaScript -->
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.9.2/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>

</html>