<?php
include('conn.php'); // Ensure this file contains the PDO connection

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve form data
    $fullname = $_POST['fullname'];
    $region = $_POST['region'];
    $gender = $_POST['gender'];
    $position = $_POST['position'];
    $amount_paid = $_POST['amount_paid'];
    $phone_number = $_POST['phone_number'];
    $province = $_POST['province'];

    // Generate registration number (initial placeholder)
    $year = date('Y');
    $registration_number = $year . '/ACC/0';

    try {
        // Check if the record already exists with the same full name or phone number
        $sql_check = "SELECT id FROM coordconf WHERE fullname = :fullname AND phone_number = :phone_number";
        $stmt_check = $conn->prepare($sql_check);
        $stmt_check->bindParam(':fullname', $fullname);
        $stmt_check->bindParam(':phone_number', $phone_number);
        $stmt_check->execute();
        $existing_id = $stmt_check->fetchColumn();

        if ($existing_id) {
            // Record already exists
            echo json_encode(array('success' => false, 'message' => 'A registration with this full name and phone number already exists.'));
            exit;
        }

        // Prepare an SQL statement to insert data into the database
        $sql_insert = "INSERT INTO coordconf (fullname, region, gender, position, amount_paid, phone_number, province, registration_number)
                       VALUES (:fullname, :region, :gender, :position, :amount_paid, :phone_number, :province, :registration_number)";

        // Prepare the statement
        $stmt_insert = $conn->prepare($sql_insert);

        // Bind parameters
        $stmt_insert->bindParam(':fullname', $fullname);
        $stmt_insert->bindParam(':region', $region);
        $stmt_insert->bindParam(':gender', $gender);
        $stmt_insert->bindParam(':position', $position);
        $stmt_insert->bindParam(':amount_paid', $amount_paid);
        $stmt_insert->bindParam(':phone_number', $phone_number);
        $stmt_insert->bindParam(':province', $province);
        $stmt_insert->bindParam(':registration_number', $registration_number);

        // Execute the statement
        $stmt_insert->execute();

        // Get the last inserted ID
        $last_id = $conn->lastInsertId();

        // Update the registration number with the ID
        $registration_number = $year . '/ACC/' . str_pad($last_id, 3, '0', STR_PAD_LEFT);

        // Prepare an SQL statement to update the registration number
        $sql_update = "UPDATE coordconf SET registration_number = :registration_number WHERE id = :id";
        $stmt_update = $conn->prepare($sql_update);
        $stmt_update->bindParam(':registration_number', $registration_number);
        $stmt_update->bindParam(':id', $last_id);
        $stmt_update->execute();

        // Return JSON response with registration number and details
        $response = array(
            'success' => true,
            'registration_number' => $registration_number,
            'fullname' => $fullname,
            'region' => $region,
            'gender' => $gender,
            'position' => $position,
            'amount_paid' => $amount_paid,
            'phone_number' => $phone_number,
            'province' => $province
        );
        echo json_encode($response);
    } catch (PDOException $e) {
        // Handle errors
        echo json_encode(array('success' => false, 'message' => 'Error: ' . $e->getMessage()));
    }

    // Close the connection
    $conn = null;
}
?>