<?php
session_start(); // Start the session

// Check if the admin is logged in
if (!isset($_SESSION['admin_id'])) {
    // If not logged in, redirect to the login page
    header("Location: admin_login.php");
    exit();
}

// Retrieve admin details from session variables
$admin_name = $_SESSION['admin_name'];
$admin_email = $_SESSION['admin_email'];
$admin_initials = $_SESSION['admin_initials'];

include ('conn.php');
// Handle create, update, and delete actions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['create'])) {
        // Create new Zoom link
        $zoomLink = $_POST['zoom_link'];
        $query = "INSERT INTO zoom (zoom_link) VALUES (:zoom_link)";
        $stmt = $conn->prepare($query);
        $stmt->execute([':zoom_link' => $zoomLink]);
    } elseif (isset($_POST['update'])) {
        // Update existing Zoom link
        $id = $_POST['id'];
        $zoomLink = $_POST['zoom_link'];
        $query = "UPDATE zoom SET zoom_link = :zoom_link WHERE id = :id";
        $stmt = $conn->prepare($query);
        $stmt->execute([':zoom_link' => $zoomLink, ':id' => $id]);
    } elseif (isset($_POST['delete'])) {
        // Delete Zoom link
        $id = $_POST['id'];
        $query = "DELETE FROM zoom WHERE id = :id";
        $stmt = $conn->prepare($query);
        $stmt->execute([':id' => $id]);
    }
}

// Fetch all Zoom links
$query = "SELECT * FROM zoom";
$stmt = $conn->prepare($query);
$stmt->execute();
$zoomLinks = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard</title>
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css" rel="stylesheet">
    <link href="imagesconf/icon2.png" rel="shortcut icon">
    <style>
    body {
        font-family: Arial, sans-serif;
        background-color: #f8f9fa;
    }

    .navbar {
        background-color: #343a40;
    }

    .navbar-brand {
        color: #fff;
        font-weight: bold;
    }

    .sidebar {
        height: 100vh;
        background-color: #343a40;
        padding-top: 20px;
    }

    .sidebar a {
        color: #ddd;
        padding: 15px;
        display: block;
        font-size: 16px;
        text-decoration: none;
    }

    .sidebar a:hover {
        background-color: #495057;
        color: #fff;
    }

    .content {
        padding: 20px;
        margin-left: 250px;
    }

    .card-header {
        background-color: #186F45;
        color: white;
        text-align: center;
    }

    .btn-primary {
        background-color: #186F45;
        border-color: #186F45;
    }

    .btn-primary:hover {
        background-color: #145536;
        border-color: #145536;
    }

    .content {
        padding: 20px;
    }

    .card {
        border: none;
        border-radius: 10px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
    }

    .card-header {
        background-color: black;
        border-bottom: 1px solid #dee2e6;
        border-top-left-radius: 10px;
        border-top-right-radius: 10px;
        padding: 15px;
    }

    .card-body {
        padding: 20px;
    }

    .table img {
        max-width: 100px;
        height: auto;
    }

    .btn-block {
        width: 100%;
    }

    .profile-image {
        display: inline-block;
        width: 40px;
        height: 40px;
        background-color: #007bff;
        color: #fff;
        text-align: center;
        line-height: 40px;
        border-radius: 50%;
        font-weight: bold;
        margin-right: 10px;
    }

    .profile-image span {
        font-size: 16px;
        text-transform: uppercase;
    }
    </style>
</head>

<body>

    <!-- Navbar -->
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">Admin Dashboard</a>
        <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
            aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav ml-auto">
                <!-- Profile Image (Initials) -->
                <li class="nav-item">
                    <div class="profile-image">
                        <span><?php echo $_SESSION['admin_initials']; ?></span>
                    </div>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#"><i class="fas fa-user-circle"></i> Profile</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="logout.php"><i class="fas fa-sign-out-alt"></i> Logout</a>
                </li>
            </ul>
        </div>
    </nav>
    <!-- Sidebar -->
    <div class="d-flex">
    <div class="sidebar">
        <a href="admin_main_header.php"><i class="fas fa-bookmark"></i> Add Main Header</a>

        <?php if ($_SESSION['user_type'] == 'superadmin') : ?>
            <!-- Show Approve Admins only for superadmin -->
            <a href="admin_approval.php"><i class="fas fa-book"></i> Approve Admins</a>
        <?php endif; ?>

        <!-- Show all other menus for both admin and superadmin -->
        <a href="about_admin.php"><i class="fas fa-tachometer-alt"></i> Add About</a>
        <a href="admin.php"><i class="fas fa-tachometer-alt"></i> Add Speakers</a>
        <a href="manage_speakers.php"><i class="fas fa-user"></i> Manage Speakers</a>
        <a href="manage_registrants.php"><i class="fas fa-user"></i> Manage Registrants</a>
        <a href="admin_schedules.php"><i class="fas fa-calendar"></i> Manage Event Schedule</a>
        <a href="admin_upload.php"><i class="fas fa-camera"></i> Add Gallery</a>
        <a href="confgallery.php"><i class="fas fa-camera"></i> Manage Gallery</a>
        <a href="admin_sponsors.php"><i class="fas fa-user"></i> Manage Sponsors</a>
        <a href="manage_sponsors.php"><i class="fas fa-briefcase"></i> List of Sponsors</a>
        <a href="admin_news.php"><i class="fas fa-book"></i> Manage News</a>
        <a href="price_table.php"><i class="fas fa-table"></i> Manage Price Table</a>
        <a href="zoom.php"><i class="fas fa-video"></i> Add Zoom Link</a>
        <a href="#"><i class="fas fa-cog"></i> Settings</a>
        <a href="#"><i class="fas fa-question-circle"></i> Help</a>
    </div>


        <!-- Admin Details Section -->
        <div class="container mt-5 flex-grow-1">
            <div class="card">
                <div class="card-header">
                    Admin Details
                </div>
                <div class="card-body">
                    <h2>Welcome, <?php echo $admin_name; ?></h2>
                    <p>Email: <?php echo $admin_email; ?></p>
                    <p>Initials: <?php echo $admin_initials; ?></p>
                </div>
            </div>

            <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">
            <img src="imagesconf/11th.png" alt="Logo">
        </a>
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
                <a class="nav-link btn btn-secondary" href="admin.php">Back to Dashboard</a>
            </li>
        </ul>
    </nav>


        <!----Addd Content----->
        <div class="container mt-5">
        <h2 class="text-center mb-4">Manage Zoom Links</h2>

        <!-- Form to create a new Zoom link -->
        <div class="card mb-4">
            <div class="card-header">
                <h4 class="mb-0">Add New Zoom Link</h4>
            </div>
            <div class="card-body">
                <form action="" method="POST">
                    <div class="form-group">
                        <label for="zoom_link">Zoom Link</label>
                        <input type="text" class="form-control" id="zoom_link" name="zoom_link" required>
                    </div>
                    <button type="submit" name="create" class="btn btn-primary">Add Zoom Link</button>
                </form>
            </div>
        </div>

        <!-- Display all Zoom links -->
        <?php if ($zoomLinks): ?>
            <?php foreach ($zoomLinks as $zoom): ?>
                <div class="card mb-4">
                    <div class="card-header">
                        <h4 class="mb-0">Zoom Link #<?= htmlspecialchars($zoom['id']) ?></h4>
                    </div>
                    <div class="card-body">
                        <p>Zoom Link: <a href="<?= htmlspecialchars($zoom['zoom_link']) ?>" target="_blank"><?= htmlspecialchars($zoom['zoom_link']) ?></a></p>

                        <!-- Form to update Zoom link -->
                        <form action="" method="POST" class="mb-2">
                            <input type="hidden" name="id" value="<?= htmlspecialchars($zoom['id']) ?>">
                            <div class="form-group">
                                <label for="zoom_link">New Zoom Link</label>
                                <input type="text" class="form-control" id="zoom_link" name="zoom_link" value="<?= htmlspecialchars($zoom['zoom_link']) ?>" required>
                            </div>
                            <button type="submit" name="update" class="btn btn-warning">Update Zoom Link</button>
                        </form>

                        <!-- Form to delete Zoom link -->
                        <form action="" method="POST">
                            <input type="hidden" name="id" value="<?= htmlspecialchars($zoom['id']) ?>">
                            <button type="submit" name="delete" class="btn btn-danger">Delete Zoom Link</button>
                        </form>
                    </div>
                </div>
            <?php endforeach; ?>
        <?php else: ?>
            <div class="card mb-4">
                <div class="card-body text-center">
                    <p>No Zoom links available.</p>
                </div>
            </div>
        <?php endif; ?>
    </div>
        <!-- Bootstrap and FontAwesome Scripts -->
        <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
        <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.2/dist/umd/popper.min.js"></script>
        <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>

</html>